@@ -5,14 +5,9 @@
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
 
-/* #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <io.h>
-#include <fcntl.h>
-#include <windef.h>*/
 
 #define __int64_t long long int
+#define uint64_t long long unsigned int
 
 #include "internal.h"
 #include "sket.h"
@@ -22,35 +17,39 @@
 #define INT_MAX 0x7fffffff
 #endif
 
-#define MY_VERSION "Avs2YUV 0.24 ADM_0.1"
+#define MY_VERSION "Avs2YUV 0.24 ADM_1.2"
 #define MAX_FH 10
-
 #include "winsock2.h"
-	int vid_width=-1;
-	int vid_height=-1;
-	int vid_fps1000=-1;
-	int vid_nbFrame=-1;
-	uint32_t currentFrame=0xFFFF0000;
-	char *Buffer;
-
-static int framePack(PVideoFrame p);
-static void handleError(void);
-static uint8_t initAvisynth(const char *infile);
-
-
+#define Log printf
+/******************************************/
+int vid_width=-1;
+int vid_height=-1;
+int vid_fps1000=-1;
+int vid_nbFrame=-1;
+uint32_t currentFrame=0xFFFF0000;
+char *Buffer;
 
 PVideoFrame Aframe=NULL;
 IScriptEnvironment* env =NULL;
 PClip clip =NULL;
 avsyInfo    info;
 
+/*****************************************/
+static int framePack(PVideoFrame p);
+static void handleError(void);
+static bool initAvisynth(const char *infile);
 
+
+/**
+	\fn main
+*/
 int __cdecl main(int argc, const char* argv[])
 {
 	const char* infile = NULL;
-	
+	char *audioBuffer=new char[48000*6*2];
+	char *audioBufferData=audioBuffer+sizeof(avsAudioFrame);
 
-	printf("AvsSocket Proxy, derivated from avs2yuv by  Loren Merritt \n");
+	printf("AvsSocket Proxy, derivated from avs2yuv by  Loren Merritt "MY_VERSION" \n");
 	fflush(stdout);
 	
 	
@@ -134,14 +133,53 @@ int __cdecl main(int argc, const char* argv[])
 					case AvsCmd_GetInfo:
 							printf("Received get info...\n");
 							fflush(stdout);
+							if(len!=8)
+							{
+									// Version
+									printf("This version of avsproxy is not compatible with the avidemux version you are using\n");
+									fflush(stdout);
+									exit( -1);
+							}
+							uint32_t api,ver;
+							api=*(uint32_t *)payload;
+							ver=*(uint32_t *)(payload+4);
+							printf("Connection from avidemux, api=%d version=%d\n",api,ver);
+							if(api!=AVSHEADER_API_VERSION)
+							{
+									printf("This version of avsproxy has api version %d, avidemux has version %d, exiting\n",AVSHEADER_API_VERSION,api);
+									fflush(stdout);
+									exit(-1);
+							}
 							sket->sendData(AvsCmd_SendInfo,0,sizeof(info),(uint8_t *)&info);
 							break;
+					case AvsCmd_GetAudio:
+							// Read payload
+							if(len!=sizeof(avsAudioFrame))
+							{
+									printf("get audio command, expected %d bytes , got %d \n",sizeof(avsAudioFrame),len);
+									fflush(stdout);
+									exit(-1);	
+							}
+							avsAudioFrame aFrame;
+							memcpy(&aFrame,payload,len);
+							// Read...
+							try {
+								clip->GetAudio(audioBufferData, aFrame.startSample, aFrame.sizeInFloatSample, env);
+							}catch(AvisynthError err) 
+							{
+								fprintf(stderr, "Get Audio :Avisynth error:\n%s\n", err.msg);	
+							    aFrame.sizeInFloatSample=0;
+							}
+							// Send reply...
+							memcpy(audioBuffer,&aFrame,sizeof(aFrame));
+							sket->sendData(AvsCmd_SendAudio,0,aFrame.sizeInFloatSample*2*info.channels+sizeof(aFrame),(uint8_t *)audioBuffer);
+							break;
 					case AvsCmd_GetFrame:
 							if(currentFrame!=frame)
 							{
 								
 							try{
-								printf("Get frame %u (old:%u)\n",frame,currentFrame);
+								Log("Get frame %u (old:%u)\n",frame,currentFrame);
 								fflush(stdout);
 								Aframe= clip->GetFrame(frame, env);
 								framePack(Aframe);	
@@ -175,12 +213,12 @@ int __cdecl main(int argc, const char* argv[])
 			}
 
 
-		}
-
-		//get(currentFrame);
-	
+		}	
 }
-
+/**
+	\fn framePack
+	\brief Pack a video frame inside our buffer
+*/
 int framePack(PVideoFrame p)
 {
 			int w,stride;
@@ -222,7 +260,9 @@ int framePack(PVideoFrame p)
 			}
 			return 1;
 }
-
+/**
+	\fn handleError
+*/
 void handleError(void)
 {
 	DWORD er=GetLastError();
@@ -231,10 +271,12 @@ void handleError(void)
 	exit(-1);
 
 }
-#if 1
+/**
+	\fn initAvisynth
+*/
 typedef IScriptEnvironment * __stdcall DLLFUNC(int);
 
-uint8_t initAvisynth(const char *infile)
+bool initAvisynth(const char *infile)
 {
 		HMODULE instance;
 		DLLFUNC *CreateScriptEnvironment=NULL;
@@ -247,7 +289,7 @@ uint8_t initAvisynth(const char *infile)
 			handleError();
 			fprintf(stderr, "failed to load avisynth.dll\n"); 
 			fflush(stderr);
-			return 2;
+			return false;
 		}
 		printf("Avisynth.dll loaded\n");
 		fflush(stdout);
@@ -255,12 +297,18 @@ uint8_t initAvisynth(const char *infile)
 		printf("Env created\n");
 		fflush(stdout);
 		if(!CreateScriptEnvironment)
-			{fprintf(stderr, "failed to load CreateScriptEnvironment()\n"); fflush(stderr); return 1;}
+		{
+			fprintf(stderr, "failed to load CreateScriptEnvironment()\n"); 
+			fflush(stderr); 
+			return false;
+		}
 try{
 		env = CreateScriptEnvironment(AVISYNTH_INTERFACE_VERSION);
 		if(!env)
 		{
-			{fprintf(stderr, "Env failed\n"); fflush(stderr); return 1;}
+			fprintf(stderr, "Env failed\n"); 
+			fflush(stderr); 
+			return false;
 		}
 		AVSValue args[]={infile};
 		printf("Importing..\n");
@@ -269,7 +317,9 @@ try{
 		clip=dummy;
 
 		VideoInfo inf = clip->GetVideoInfo();
-	
+	    memset(&info,0,sizeof(info));
+		info.version=AVSHEADER_API_VERSION;
+		// Video part
 		info.width=vid_width=inf.width;
 		info.height=vid_height=inf.height;
 		info.fps1000=vid_fps1000=(inf.fps_numerator*1000)/inf.fps_denominator;
@@ -280,59 +330,55 @@ try{
 		f/=inf.fps_denominator;
 		vid_fps1000=info.fps1000=(uint32_t)ceil(f);
 		info.nbFrames=vid_nbFrame=inf.num_frames;
-		
+		// audio part
+		info.frequency=inf.SamplesPerSecond(); // 0 means no audio
+		info.channels=inf.AudioChannels();
+		if(info.frequency)
+		{
+			if(inf.SampleType()!=SAMPLE_INT16)
+			{
+				printf("Only int16 for audio and not %d!\n",(int)inf.SampleType());
+				fflush(stdout);
+				handleError();
+				return false;	
+			}
+		}
 		if(!inf.IsYV12()) 
 		{
 			printf("Only yv12!\n");
 			fflush(stdout);
 			handleError();
+			return false;
 		}
 		if(!inf.IsYV12())
-			{fprintf(stderr, "Couldn't convert input to YV12\n"); fflush(stderr); return 1;}
+			{fprintf(stderr, "Couldn't convert input to YV12\n"); fflush(stderr); return false;}
 		if(inf.IsFieldBased())
-			{fprintf(stderr, "Needs progressive input\n"); fflush(stderr); return 1;}
+			{fprintf(stderr, "Needs progressive input\n"); fflush(stderr); return false;}
 
 	
 		// Incoming ready
-		printf("Info\n");
-		printf("Width   :%d \n",vid_width);
-		printf("Height  :%d \n",vid_height);
-		printf("Fps1K   :%d \n",vid_fps1000);
-		printf("NbFrame :%d \n",vid_nbFrame);
+		printf("Clip Info\n");
+		printf("_________\n");
+		printf("Width     :%d \n",vid_width);
+		printf("Height    :%d \n",vid_height);
+		printf("Fps1K     :%d \n",vid_fps1000);
+		printf("NbFrame   :%d \n",vid_nbFrame);
+		printf("Frequency :%d \n",info.frequency);
+		printf("#channels :%d \n",info.channels);
 		fflush(stdout);
+		return true;
 }
 catch(AvisynthError err) {
 		
 			fprintf(stderr, "\nAvisynth error:\n%s\n", err.msg);
 			fflush(stderr);
-		return 1;
+		return false;
 	}
 
 
 
-		return 1;
+		return true;
 }
 
-#else
-typedef IScriptEnvironment * __stdcall FUNC(int);
-uint8_t initAvisynth(const char *infile)
-{
-HINSTANCE lib = LoadLibrary("avisynth.dll");
-FUNC *func = (FUNC *)GetProcAddress(lib, "CreateScriptEnvironment");
-IScriptEnvironment *env = func(AVISYNTH_INTERFACE_VERSION);
-
-{
-	AVSValue args[] = { infile };
-	PClip clip(env->Invoke("Import", AVSValue(args, 1)).AsClip());
-	const VideoInfo& vi = clip->GetVideoInfo();
-
-	printf("%d %d %d", vi.width, vi.height, vi.BitsPerPixel());
-}
-
-delete env;
-FreeLibrary(lib);
-return 1;
-}
-#endif
 //EOF
 
