@@ -23,13 +23,12 @@
 #include <stdlib.h>
 #include <string.h>
 //#include <stream.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 
 #include "config.h"
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "avio.hxx"
 #include "fourcc.h"
 #include "aviaudio.hxx"
 
