@@ -23,13 +23,12 @@
 #include <stdlib.h>
 #include <string.h>
 //#include <stream.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 
 #include "config.h"
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "avio.hxx"
 #include "fourcc.h"
 #include "aviaudio.hxx"
 #include "ADM_outputs/oplug_avi/avilist.h"
@@ -532,4 +531,23 @@ uint8_t AVDMGenericAudioStream::endWrite(FILE * out, uint32_t len)
     return 1;
 
 }
+/**
+ * 	\fn ADM_audioCompareChannelMapping
+ *  \brief return true if the two channel mapping are identical, false else.
+ */
+bool ADM_audioCompareChannelMapping(WAVHeader *wh1, WAVHeader *wh2,CHANNEL_TYPE *map1,CHANNEL_TYPE *map2)
+{
+	if(wh1->channels != wh2->channels) return false; // cannot be identical..
+		
+			for (int j = 0; j < wh1->channels; j++)
+			{
+				if (map1[j] != map2[j]) 
+				{
+					return false;
+					
+				}
+			}
+	return true;
+}
+
 //
