@@ -18,22 +18,15 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-//#include <stream.h>
-#include <ADM_assert.h>
+#include "ADM_default.h"
 #include <math.h>
-
 #include "config.h"
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "avio.hxx"
 #include "fourcc.h"
 #include "aviaudio.hxx"
 #include "prefs.h"
 
-#include "ADM_toolkit/toolkit.hxx"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
 #include "ADM_libraries/ADM_utilities/avidemutils.h"
 
