@@ -18,13 +18,12 @@
 #include <stdlib.h>
 #include <string.h>
 //#include <sstream>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 
 #include "config.h"
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "avio.hxx"
 #include "fourcc.h"
 //#include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
