@@ -16,30 +16,23 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-//#include <sstream>
-#include <ADM_assert.h>
+#include "ADM_default.h"
 #include <math.h>
 
-#include "config.h"
+
 #include "avifmt.h"
 #include "avifmt2.h"
-#include "avio.hxx"
-#include "fourcc.h"
-//#include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
-#include "ADM_audiofilter/audiofilter_channel_route.h"
+
 
 ADM_AudiocodecWavSwapped::ADM_AudiocodecWavSwapped( uint32_t fourcc ) : ADM_Audiocodec(fourcc)
 {
-	ch_route.input_type[0] = CH_FRONT_LEFT;
-	ch_route.input_type[1] = CH_FRONT_RIGHT;
-	ch_route.input_type[2] = CH_FRONT_CENTER;
-	ch_route.input_type[3] = CH_LFE;
-	ch_route.input_type[4] = CH_REAR_LEFT;
-	ch_route.input_type[5] = CH_REAR_RIGHT;
+	channelMapping[0] = CHTYP_FRONT_LEFT;
+	channelMapping[1] = CHTYP_FRONT_RIGHT;
+	channelMapping[2] = CHTYP_FRONT_CENTER;
+	channelMapping[3] = CHTYP_LFE;
+	channelMapping[4] = CHTYP_REAR_LEFT;
+	channelMapping[5] = CHTYP_REAR_RIGHT;
 }
 
 ADM_AudiocodecWavSwapped::~ADM_AudiocodecWavSwapped()
