@@ -23,10 +23,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
 #include <math.h>
 
-#include "ADM_utilities/default.h"
+#include "ADM_default.h"
 
 
 #include "audioprocess.hxx"
