@@ -26,10 +26,6 @@
 
 
 #include "audioencoder.h"
-
-#include "ADM_audiocodec/ADM_audiocodeclist.h"
-
-
 #include "audiofilter_bridge.h"
 #include "audiofilter_mixer.h"
 #include "audiofilter_normalize.h"
@@ -62,7 +58,8 @@ static const externalSource Sources[]=
         {AudioAC3,"AC3"},
         {AudioNone,"NONE"}
 };
-typedef struct Mixer_String
+
+struct Mixer_String
 {
   const char         *name;
   CHANNEL_CONF conf;
