@@ -12,23 +12,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include "ADM_default.h"
 #include <math.h>
 
-#include <ADM_assert.h>
-
-
-#include "avifmt.h"
-#include "avifmt2.h"
-// Needed for incoming ..
-#include "audioprocess.hxx"
-
-#include "audioeng_process.h"
-
+#include "ADM_audioFilter.h"
 #include "audiofilter_bridge.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
@@ -177,5 +165,15 @@ uint8_t AUDMAudioFilter_Bridge::fillIncomingBuffer(AUD_Status *status)
   }
   return 1;
 }
-
+/**
+ * 	\fn return _incoming->getChannelMapping();
+ * \brief since it is a bridge, we translate the filter channel mapping from the audiostream channel mapping
+ */
+CHANNEL_TYPE *AUDMAudioFilter_Bridge::getChannelMapping(void) 
+{
+	ADM_assert(_incoming);
+	CHANNEL_TYPE *chan=_incoming->getChannelMapping();
+	ADM_assert(chan);
+	return chan;
+}
 //EOF
