@@ -20,17 +20,11 @@
 #include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+
 #include <math.h>
 
-#include <ADM_assert.h>
-
-#include "avifmt.h"
-#include "avifmt2.h"
-
-#include "ADM_toolkit/toolkit.hxx"
-//#include "ADM_dialog/DIA_working.h"
-#include "audioeng_process.h"
+#include "ADM_default.h"
+#include "ADM_audioFilter.h"
 #include "audiofilter_normalize_param.h"
 #include "audiofilter_normalize.h"
 #include "audiofilter_dolby.h"
@@ -40,15 +34,12 @@
 
 extern AVDMGenericAudioStream *currentaudiostream;
 
-
-#ifndef ADM_WIN32
-#ifdef ADM_BSD_FAMILY
-                #define POW10(x) powf(10.0,x)
+#ifdef __WIN32
+#define POW10(x)   pow(10,x)
+#elif defined(ADM_BSD_FAMILY)
+#define POW10(x) powf(10.0,x)
 #else
-                #define POW10(x)  pow10f(x)
-#endif
-#else
-                #define POW10(x)   pow(10,x)
+#define POW10(x)  pow10f(x)
 #endif
 
 #define LINEAR_TO_DB(x) (20.*log10(x))
