@@ -17,15 +17,13 @@
 #ifndef __CODECS__
 #define __CODECS__
 #include "ADM_image.h"
-
-#define AVI_KEY_FRAME	0x10
-#define AVI_B_FRAME	0x4000	// hopefully it is not used..
-#define AVI_P_FRAME   	0x0
-
+#include "ADM_codecFrameType.h"
 #define ADM_QPEL_ON	1
 #define ADM_GMC_ON	2
 #define ADM_VOP_ON	4
 
+#define ADM_ENC_REQ_NULL_FLUSH	1
+
 /*
         Bitrate in configuration will always be in **kBITS**
 
@@ -127,10 +125,6 @@ public:
   virtual uint8_t compress (ADMImage * in, ADMBitstream * out);
 };
 decoders *getCoder (uint32_t fcc, uint32_t w, uint32_t h);
-uint8_t isMpeg4Compatible (uint32_t fourcc);
-uint8_t isH264Compatible (uint32_t fourcc);
-uint8_t isMSMpeg4Compatible (uint32_t fourcc);
-uint8_t isDVCompatible (uint32_t fourcc);
 
 /*----------------------------------------------------------*/
 class encoder
