@@ -13,7 +13,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_image.h"
 #include "ADM_editor/ADM_edCache.h"
 #include "ADM_assert.h"
