@@ -22,15 +22,13 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "config.h"
 #include "fourcc.h"
-#include "avio.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_codecs/ADM_codec.h"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter.h"
 #include "avi_vars.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
@@ -520,7 +518,8 @@ ADMCompressedImage img;
 
 	// we do postproc !
 	// keep
-	uint8_t *oBuff[3],*iBuff[3];
+	uint8_t *oBuff[3];
+	const uint8_t *iBuff[3];
 	int	strideTab[3];
 	int	strideTab2[3];
 	aviInfo _info;
