@@ -1,16 +1,18 @@
 #ifndef ADM_CODEC_CONFIG_
 #define ADM_CODEC_CONFIG_
 
-#define REQUANT_AS_CODE
 #include "ADM_vidEncode.hxx"
 // Yv12
 extern uint8_t DIA_requant(COMPRES_PARAMS *incoming);
 
-COMPRES_PARAMS yv12codec = {
-  CodecYV12,
+CODEC_INFO yv12codecInfo = {
   QT_TR_NOOP("YV12 (raw)"),
   "YV12",
-  "YV12",
+  "YV12"
+};
+
+COMPRES_PARAMS yv12codec = {
+  CodecYV12,
   COMPRESS_CQ,
   1,
   1500,
@@ -23,13 +25,16 @@ COMPRES_PARAMS yv12codec = {
   NULL
 };
 
-#if defined REQUANT_AS_CODE
 uint32_t RequantFactorExtra=1000; // 1000* the actual requant factor
-COMPRES_PARAMS RequantCodec = {
-    CodecRequant,
+
+CODEC_INFO RequantCodecInfo = {
     QT_TR_NOOP("MPEG-2 requant"),
     "REQUANT",
-    "Mpeg2 Requantizer",
+    "Mpeg2 Requantizer"
+};
+
+COMPRES_PARAMS RequantCodec = {
+    CodecRequant,
     COMPRESS_CQ,
     4,
     1500,
@@ -41,24 +46,29 @@ COMPRES_PARAMS RequantCodec = {
     sizeof (RequantFactorExtra),
     DIA_requant
 };
-#endif
 
-COMPRES_PARAMS DUMMYONE =
-  { CodecDummy, QT_TR_NOOP("dummy"), "dummy", "dummy", COMPRESS_CQ, 4, 1500, 700,1000, 0, 0,
-NULL, 0 };
-COMPRES_PARAMS CopyCodec =
-  { CodecCopy, QT_TR_NOOP("Copy"), "Copy", "Copy", COMPRESS_CQ, 4, 1500, 700,1000, 0, 0, NULL,
-0 };
+CODEC_INFO CopyCodecInfo = {
+	QT_TR_NOOP("Copy"),
+	"Copy",
+	"Copy"
+};
+
+COMPRES_PARAMS CopyCodec = { CodecCopy, COMPRESS_CQ, 4, 1500, 700,1000, 0, 0, NULL, 0 };
+
+CODEC_INFO *internalVideoCodecInfo[] = {
+  &CopyCodecInfo,
+  &RequantCodecInfo,
+  &yv12codecInfo
+};
 
 COMPRES_PARAMS *internalVideoCodec[] = {
   &CopyCodec,
   &RequantCodec,
-  &yv12codec,
-  &DUMMYONE
+  &yv12codec
 };
 
 int getInternalVideoCodecCount()
 {
-	return (sizeof(internalVideoCodec) / sizeof(COMPRES_PARAMS*)) - 1;	// There is a dummy extra one at the end
+	return (sizeof(internalVideoCodec) / sizeof(COMPRES_PARAMS*));
 }
 #endif
