@@ -21,25 +21,16 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <unistd.h>
-
-#include <time.h>
-#include <sys/time.h>
-
+#include "config.h"
+#include "ADM_default.h"
 
 #include "fourcc.h"
 #include "avi_vars.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
+
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encCopy.h"
 
@@ -111,7 +102,7 @@ EncoderCopy::getFCCHandler (void)
 
 /****************************************************************/
 uint8_t
-EncoderCopy::configure (AVDMGenericVideoStream * instream)
+EncoderCopy::configure (AVDMGenericVideoStream * instream, int useExistingLogFile)
 {
   aviInfo info;
   _in = instream;
