@@ -12,25 +12,17 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <unistd.h>
-
-#include <time.h>
-#include <sys/time.h>
+#include "config.h"
 
 
 #include "fourcc.h"
 #include "avi_vars.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
+
+#include "ADM_assert.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encRequant.h"
 
@@ -118,7 +110,7 @@ EncoderRequant::getFCCHandler (void)
 
 /****************************************************************/
 uint8_t
-EncoderRequant::configure (AVDMGenericVideoStream * instream)
+EncoderRequant::configure (AVDMGenericVideoStream * instream, int useExistingLogFile)
 {
   aviInfo info;
   _in = instream;
