@@ -26,6 +26,7 @@
 #define __ADM_encoder__
 #include "ADM_image.h"
 #include "ADM_bitstream.h"
+#include "ADM_videoFilter.h"
 typedef enum
 {
 
@@ -81,7 +82,7 @@ public:
   virtual ~ Encoder (void);
   virtual int getRequirements (void) = 0;
   virtual uint8_t isDualPass (void) = 0;
-  virtual uint8_t configure (AVDMGenericVideoStream * instream) = 0;
+  virtual uint8_t configure (AVDMGenericVideoStream * instream, int useExistingLogFile) = 0;
   virtual uint8_t encode (uint32_t frame, ADMBitstream * out) = 0;
   virtual uint8_t stop (void) = 0;
   virtual uint8_t setLogFile (const char *o, uint32_t frames) = 0;
@@ -100,8 +101,7 @@ public:
 
 
 };
-Encoder *getVideoEncoder (uint32_t w, uint32_t h, uint32_t globalHeader = 0);
-
+Encoder *getVideoEncoder (uint32_t globalHeader = 0);
 
 typedef enum
 {
@@ -111,9 +111,7 @@ typedef enum
 } CodecFamilty;
 
 extern CodecFamilty videoCodecGetFamily (void);
-extern void videoCodecConfigureUI (void);
+extern void videoCodecConfigureUI(int codecIndex = -1);
 extern int videoCodecConfigure (char *p, uint32_t i, uint8_t * c);
 extern void videoCodecSelect (void);
-extern void videoCodecSetcodec (SelectCodecType codec);
-extern uint8_t EncoderSaveMpeg (const char *name);
 #endif
