@@ -15,25 +15,17 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <unistd.h>
-
-#include <time.h>
-#include <sys/time.h>
+#include "config.h"
 
 
 #include "fourcc.h"
 #include "avi_vars.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
+
+#include "ADM_assert.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encyv12.h"
 
@@ -54,7 +46,7 @@ EncoderYV12::~EncoderYV12 ()
 };
 //--------------------------------
 uint8_t
-EncoderYV12::configure (AVDMGenericVideoStream * instream)
+EncoderYV12::configure (AVDMGenericVideoStream * instream, int useExistingLogFile)
 {
   ADM_assert (instream);
   ADV_Info *info;
