@@ -15,22 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
- #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include "ADM_assert.h"
-
 #include "config.h"
-#include "fourcc.h"
-#include "avio.hxx"
-#include "avi_vars.h"
+#if 0 // OBSOLETE
 
+#include "ADM_default.h"
 
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_videoFilter/ADM_vidFlipV.h"
-#include "ADM_filter/video_filters.h"
 
 //#define REDUCED
 //adm_fast_memcpy myAdmMemcpy=memcpy;
@@ -43,12 +34,12 @@ extern "C"
 {
 SCRIPT_CREATE(FILTER_create_fromscript,ADMVideoFlipV,flipParam);
 BUILD_CREATE(FILTER_create,ADMVideoFlipV);
-const char *FILTER_getName(void)
+char *FILTER_getName(void)
 {
 	return "DynFLIPPER";
 }
 
-const char *FILTER_getDesc(void)
+char *FILTER_getDesc(void)
 {
 	return "Vertical flip, demo for dynamically loaded filters";
 }
@@ -144,5 +135,5 @@ uint8_t ADMVideoFlipV::getFrameNumberNoAlloc(uint32_t frame,
 	return 1;
 }
 
-
+#endif
 
