@@ -22,19 +22,17 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <string.h>
+#include <math.h>
 
-#include "math.h"
-
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_editor/ADM_Video.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "fourcc.h"
-#include "ADM_h263/ADM_h263.h"
-#include "ADM_h263/bitsRead.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_h263.h"
+#include "bitsRead.h"
+#include "DIA_coreToolkit.h"
 
 #ifdef H263_VERBOSE
 #define ONEOPT(x) {if(parser->read1bit()) printf(x);			}
