@@ -22,7 +22,7 @@
 #include "config.h"
 #include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
 #include "avifmt.h"
 #include "avifmt2.h"
 
@@ -30,8 +30,8 @@
 #include "ADM_audio/aviaudio.hxx"
 
 #include "fourcc.h"
-#include <ADM_assert.h>
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_assert.h"
+
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_MPEG_DEMUX
