@@ -16,12 +16,12 @@
  ***************************************************************************/
  #ifndef MPX_AUDIO
  #define MPX_AUDIO
-#include "ADM_mpegdemuxer/dmx_demuxer.h"
-#include "ADM_mpegdemuxer/dmx_demuxerEs.h"
-#include "ADM_mpegdemuxer/dmx_demuxerPS.h"
-#include "ADM_mpegdemuxer/dmx_demuxerTS.h"
-#include "ADM_mpegdemuxer/dmx_demuxerMSDVR.h"
- #include "ADM_audio/aviaudio.hxx"
+#include "dmx_demuxer.h"
+#include "dmx_demuxerEs.h"
+#include "dmx_demuxerPS.h"
+#include "dmx_demuxerTS.h"
+#include "dmx_demuxerMSDVR.h"
+#include "ADM_audio/aviaudio.hxx"
 
 #define DMX_MAX_TRACK 16
 
