@@ -21,8 +21,8 @@
 #include <string.h>
 #include <math.h>
 
-#include "default.h"
-#include <ADM_assert.h>
+#include "ADM_default.h"
+#include "ADM_assert.h"
 
 
 #include "dmx_demuxer.h"
