@@ -25,7 +25,7 @@
 #include "config.h"
 #include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_assert.h"
 
 #include "dmx_io.h"
@@ -71,7 +71,7 @@ fileParser::~fileParser()
 */
 uint8_t fileParser::open( const char *filename,FP_TYPE *multi )
 {
-        char *dot = NULL;                   // pointer to the last dot in filename
+        const char *dot = NULL;                   // pointer to the last dot in filename
         uint8_t decimals = 0;               // number of decimals
         char *left = NULL, *number = NULL, *right = NULL; // parts of filename (after splitting)
 
