@@ -8,10 +8,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include <math.h>
 #include "config.h"
-#include <default.h>
+#include "ADM_default.h"
 
 #ifndef UNUSED_ARG
 	#define UNUSED_ARG(x) if(x) {}
@@ -19,7 +19,7 @@
 
 
 #if !defined(_I386_TYPES_H) || defined(ADM_BIG_ENDIAN)
-#include "default.h"
+
 typedef uint8_t __u8;
 typedef uint16_t __u16;
 typedef uint32_t __u32;
@@ -31,7 +31,7 @@ typedef int32_t __s32;
 
 #include "ADM_rtGlob.h"
 extern "C" {
-	#include "ADM_nuv/RTjpeg.h"
+	#include "RTjpeg.h"
 };
 
  	int 		baseRT::SetSize(int *w, int *h)
