@@ -22,10 +22,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "math.h"
-#include <ADM_assert.h>
+#include <math.h>
+#include "ADM_assert.h"
 
-#include "default.h"
+#include "ADM_default.h"
 #include "fourcc.h"
 
 #include "ADM_ogm.h"
