@@ -111,7 +111,13 @@ int64_t startOfData;
                          run++;
                 }
         }
-        ADM_assert(run==_nbAudioTracks);
+        if(!run) 
+        {
+            _nbAudioTracks=0;
+            printf("No audio chunk found in index..\n");
+        }else
+            ADM_assert(run==_nbAudioTracks);
+
 
         // Create index
         uint32_t nb;
