@@ -15,8 +15,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include "default.h"
-#include <ADM_assert.h>
+#include "ADM_default.h"
+#include "ADM_assert.h"
 
 #include "ADM_riff.h"
 
@@ -30,7 +30,7 @@
 
 uint64_t riffParser::getPos( void ) 
 { 
-#ifdef ADM_WIN32
+#ifdef __WIN32
         aprintf("pos : %I64u / %I64u \n",curPos,ftello(fd));
 #else
 	aprintf("pos : %llu / %llu \n",curPos,ftello(fd));
@@ -59,7 +59,7 @@ uint8_t riffParser::skip(uint32_t s)
 }
 uint8_t riffParser::endReached(void)
 {
-#ifdef ADM_WIN32
+#ifdef __WIN32
         aprintf("Cur : %I64u end : %I64u left: %I64u\n",curPos,endPos,endPos-curPos);
 #else
 	aprintf("Cur : %llu end : %llu left: %llu\n",curPos,endPos,endPos-curPos);
