@@ -21,35 +21,24 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <math.h>
-#include <string.h>
 #include <sys/stat.h>
-#include <pthread.h>
-#define WIN32_CLASH
+
+#include "ADM_default.h"
+#include "ADM_threads.h"
+
 #include "interact.hpp"
 
 #undef malloc
 #undef realloc
 #undef free
-#include <ADM_assert.h>
 
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
 
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "ADM_audio/ADM_a52info.h"
-
-//#include "ADM_codecs/ADM_codec.h"
 #include "avifmt.h"
 #include "avifmt2.h"
 #include "ADM_editor/ADM_Video.h"
-
-#include "ADM_lavformat/ADM_lavformat.h"
-
+#include "ADM_outputs/ADM_lavformat.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_LAVFORMAT
