@@ -17,7 +17,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "ADM_assert.h"
-#include "default.h"
+#include "ADM_default.h"
 #include "ADM_bitstream.h"
 
 
