@@ -11,18 +11,15 @@
  *                                                                         *
  ***************************************************************************/
  #include "config.h"
- #include <stdio.h>
- #include <stdlib.h>
- #include <string.h>
- #include "ADM_assert.h"
- #include "default.h"
+#include "ADM_default.h"
 
  #include "ADM_editor/ADM_edit.hxx"
- #include "ADM_video/ADM_genvideo.hxx"
-
+ #include "ADM_videoFilter.h"
  #include "ADM_ocr.h"
  #include "ADM_ocrInternal.h"
- #include "ADM_toolkit/toolkit.hxx"
+ #include "DIA_coreToolkit.h"
+
+#include "ADM_video/ADM_vidMisc.h"
 
 /**************************
  *  UI Dependant part
