@@ -22,31 +22,27 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
+#include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include "ADM_default.h"
 #include <math.h>
-#include <unistd.h>
-#include <string.h>
-
 
 #include <time.h>
 #include <sys/time.h>
 
-//#define TEST_V2V
+#include "DIA_coreToolkit.h"
 
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_assert.h"
 
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiofilter/audioprocess.hxx"
 
-#include "ADM_toolkit/filesel.h"
-#include "ADM_mpegdemuxer/dmx_demuxer.h"
-#include "ADM_mpegdemuxer/dmx_demuxerPS.h"
+#include "DIA_fileSel.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_demuxer.h"
+#include "ADM_inputs/ADM_mpegdemuxer/dmx_demuxerPS.h"
 #include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
+
+#include "ADM_video/ADM_vidMisc.h"
+
 #define ADM_VOBSUB_NO_PADDING
 static int vobsub_parse_ifo(const char *const name, 
                      uint32_t *palette, 
