@@ -13,11 +13,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 
 #include "fourcc.h"
-#include "avio.hxx"
+
 #include "config.h"
 #include "avi_vars.h"
 
