@@ -7,18 +7,18 @@ char* ms2timedisplay(uint32_t ms)
 {
 	uint32_t mm, ss;
 #define ADM_MAX_STRING 256
-#define LU "u"
+
 	static char string[ADM_MAX_STRING+1];
 
 	mm = (uint32_t)floor(ms / 60000.);
 	
 	if (mm > 1)
 	{
-		snprintf(string, ADM_MAX_STRING,QT_TR_NOOP("%"LU" minutes"), mm);
+		snprintf(string, ADM_MAX_STRING,QT_TR_NOOP("%u minutes"), mm);
 	}
 	else if (mm == 1)
 	{
-		snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%"LU" minute"), mm);
+		snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%u minute"), mm);
 	}
 	else
 	{
@@ -26,11 +26,11 @@ char* ms2timedisplay(uint32_t ms)
 
 		if (ss == 1)
 		{
-			snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%"LU" second"), ss);
+			snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%u second"), ss);
 		}
 		else
 		{
-			snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%"LU" seconds"), ss);
+			snprintf(string,ADM_MAX_STRING, QT_TR_NOOP("%u seconds"), ss);
 		}
 	}
     string[ADM_MAX_STRING]=0;
