@@ -12,9 +12,10 @@
 #ifndef OP_OGSAVE
 #define OP_OGSAVE
 
-#include "DIA_encoding.h"
-#include "oplug_ogm/op_ogpage.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_encoding.h"
+#include "op_ogpage.h"
 #include "ADM_encoder/adm_encoder.h"
+
 // Some little / big endian stuff
 extern void memcpyswap(uint8_t *dest, uint8_t *src, uint32_t size);
 #ifdef ADM_BIG_ENDIAN	
