@@ -55,13 +55,13 @@
 
 
 // MEANX
-#include "default.h"
+#include "ADM_default.h"
 #include "tcrequant.h"
 
-#include "../ADM_osSupport/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_TCREQUANT
-#include "../ADM_osSupport/ADM_debug.h"
-#include "../ADM_assert.h"
+#include "ADM_osSupport/ADM_debug.h"
+
 
 // / MEANX
  void mixDump_c(uint8_t *p, uint32_t l);
@@ -85,7 +85,7 @@ static int verbose = 2;
 
 // user defined types
 //typedef unsigned int		uint;
-#ifdef ADM_WIN32
+#ifdef __WIN32
 	#define uint unsigned int
 #endif
 #ifdef ADM_BSD_FAMILY
