@@ -10,36 +10,26 @@
 //
 //
 
-#include <config.h>
-#include <stdlib.h>
+#include "ADM_default.h"
+#include "config.h"
 #include "ADM_JSGlobal.h"
 #include "ADM_JSAvidemuxAudio.h"
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
+
 #include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
-#include "ADM_audiofilter/audioeng_buildfilters.h"
-#include "avi_vars.h"
 #include "gui_action.hxx"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_encoder/adm_encoder.h"
-#include "ADM_encoder/adm_encConfig.h"
-#include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_filter/video_filters.h"
-
-
-#include "ADM_script/ADM_container.h"
+#include "ADM_JSAudioTrackInfo.h"
 
 extern int A_audioSave(char *name);
 extern int A_loadAC3 (char *name);
 extern int A_loadMP3 (char *name);
 extern int A_loadWave (char *name);
+extern AudioSource currentAudioSource;
+extern AudioSource secondAudioSource;
 extern void HandleAction(Action act);
 extern uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name);
 
-JSPropertySpec ADM_JSAvidemuxAudio::avidemuxaudio_properties[] = 
-{ 
-
+JSPropertySpec ADM_JSAvidemuxAudio::properties[] = {
         { "process", audioprocess_prop, JSPROP_ENUMERATE },        // process audio when saving
         { "resample", resample_prop, JSPROP_ENUMERATE },	// resample
         { "delay", delay_prop, JSPROP_ENUMERATE },	// set audio delay
@@ -48,22 +38,20 @@ JSPropertySpec ADM_JSAvidemuxAudio::avidemuxaudio_properties[] =
         { "normalizeMode", normalizemode_prop, JSPROP_ENUMERATE },	//
         { "drc", drc_prop, JSPROP_ENUMERATE },	//
         { "normalizeValue", normalizevalue_prop, JSPROP_ENUMERATE },	//
+		{ "mixer", mixerProperty, JSPROP_ENUMERATE },	//
+		{ "sourceTrackInfo", sourceTrackInfoProperty, JSPROP_ENUMERATE },
+		{ "targetTrackInfo", targetTrackInfoProperty, JSPROP_ENUMERATE },
         { 0 }
 };
 
-JSFunctionSpec ADM_JSAvidemuxAudio::avidemuxaudio_methods[] = 
-{
-        { "scanVBR", ScanVBR, 0, 0, 0 },	// scan variable bit rate audio
+JSFunctionSpec ADM_JSAvidemuxAudio::methods[] = {
+        { "scanVbr", ScanVBR, 0, 0, 0 },	// scan variable bit rate audio
         { "save", Save, 1, 0, 0 },	// save audio stream
         { "load", Load, 2, 0, 0 },	// load audio stream
         { "reset", Reset, 0, 0, 0 },	// reset audio stream
         { "codec", Codec, 4, 0, 0 },	// set output codec
-        { "getNbTracks", getNbTracks, 0, 0, 0 },    // set output codec
         { "setTrack", setTrack, 1, 0, 0 },    // set output codec
         { "secondAudioTrack", secondAudioTrack, 2, 0, 0 },    // set audio track
-        { "mixer", mixer, 1, 0, 0 },    // set mixer configuration
-        { "getNbChannels", getNbChannels, 1, 0, 0 },
-        { "getBitrate", getBitrate, 1, 0, 0 },
         { 0 }
 };
 
@@ -95,25 +83,14 @@ ADM_AvidemuxAudio *ADM_JSAvidemuxAudio::getObject()
 
 JSObject *ADM_JSAvidemuxAudio::JSInit(JSContext *cx, JSObject *obj, JSObject *proto)
 {
-        JSObject *newObj = JS_InitClass(cx, obj, proto, &m_classAvidemuxAudio, 
-                                                                        ADM_JSAvidemuxAudio::JSConstructor, 0,
-                                                                        ADM_JSAvidemuxAudio::avidemuxaudio_properties, ADM_JSAvidemuxAudio::avidemuxaudio_methods,
-                                                                        NULL, NULL);
-        return newObj;
-}
+	JSObject *newObj = JS_InitClass(cx, obj, proto, &m_classAvidemuxAudio, NULL, 0,
+		ADM_JSAvidemuxAudio::properties, ADM_JSAvidemuxAudio::methods, NULL, NULL);
+	ADM_JSAvidemuxAudio *p = new ADM_JSAvidemuxAudio();
 
-JSBool ADM_JSAvidemuxAudio::JSConstructor(JSContext *cx, JSObject *obj, uintN argc, 
-                                                                jsval *argv, jsval *rval)
-{
-        if(argc != 0)
-                return JS_FALSE;
-        ADM_JSAvidemuxAudio *p = new ADM_JSAvidemuxAudio();
-        ADM_AvidemuxAudio *pObject = new ADM_AvidemuxAudio();
-        p->setObject(pObject);
-        if ( ! JS_SetPrivate(cx, obj, p) )
-                return JS_FALSE;
-        *rval = OBJECT_TO_JSVAL(obj);
-        return JS_TRUE;
+	p->setObject(new ADM_AvidemuxAudio());
+	JS_SetPrivate(cx, newObj, p);
+
+	return newObj;
 }
 
 void ADM_JSAvidemuxAudio::JSDestructor(JSContext *cx, JSObject *obj)
@@ -155,14 +132,65 @@ JSBool ADM_JSAvidemuxAudio::JSGetProperty(JSContext *cx, JSObject *obj, jsval id
                         case drc_prop:
                             *vp = BOOLEAN_TO_JSVAL(priv->getObject()->m_bDRC);
                             break;
-/*
-                        case audio_prop:
-                                *vp = OBJECT_TO_JSVAL(priv->getObject()->m_pAudio);
-                                break;
-*/
-                }
-        }
-        return JS_TRUE;
+						case mixerProperty:
+							*vp = STRING_TO_JSVAL(JS_NewStringCopyZ(cx, getCurrentMixerString()));
+							break;
+						case sourceTrackInfoProperty:
+						{
+							JSObject *tracks = JS_NewArrayObject(cx, 0, NULL);
+							jsval sourceTrack;
+
+							audioInfo *audioInfos = NULL;
+							uint32_t trackCount = 0;
+
+							*vp = OBJECT_TO_JSVAL(tracks);
+							video_body->getAudioStreamsInfo(0, &trackCount, &audioInfos);
+
+							for (int infoIndex = 0; infoIndex < trackCount; infoIndex++)
+							{
+								sourceTrack = OBJECT_TO_JSVAL(ADM_JSAudioTrackInfo::JSInit(cx, obj, NULL, infoIndex, (&audioInfos)[infoIndex]));
+								JS_SetElement(cx, tracks, infoIndex, &sourceTrack);
+							}
+
+							if(audioInfos)
+								delete [] audioInfos;
+
+							break;
+						}
+						case targetTrackInfoProperty:
+						{
+							JSObject *tracks = JS_NewArrayObject(cx, 0, NULL);
+							jsval targetTrack;
+
+							*vp = OBJECT_TO_JSVAL(tracks);
+
+							AddAudioSourceToJSArray(cx, obj, 0, currentAudioSource, currentaudiostream, tracks);
+							AddAudioSourceToJSArray(cx, obj, 1, secondAudioSource, secondaudiostream, tracks);
+
+							break;
+						}
+				}
+		}
+
+		return JS_TRUE;
+}
+
+void ADM_JSAvidemuxAudio::AddAudioSourceToJSArray(JSContext *cx, JSObject *obj, int trackIndex, AudioSource audioSource, 
+												  AVDMGenericAudioStream *audioStream, JSObject *tracks)
+{
+	if (audioStream != NULL)
+	{
+		WAVHeader *trackHeader = audioStream->getInfo();
+
+		jsval targetTrack = OBJECT_TO_JSVAL(ADM_JSAudioTrackInfo::JSInit(
+			cx, obj, NULL, 
+			audioSource == AudioAvi ? video_body->getCurrentAudioStreamNumber(trackIndex) : -1,
+			trackIndex, trackHeader));
+		jsuint length;
+
+		JS_GetArrayLength(cx, tracks, &length);
+		JS_SetElement(cx, tracks, length, &targetTrack);
+	}
 }
 
 JSBool ADM_JSAvidemuxAudio::JSSetProperty(JSContext *cx, JSObject *obj, jsval id, jsval *vp)
@@ -250,6 +278,13 @@ JSBool ADM_JSAvidemuxAudio::JSSetProperty(JSContext *cx, JSObject *obj, jsval id
                                   leaveLock();
                                   break;
                         }
+						case mixerProperty:
+						{
+							const char *mixer = JS_GetStringBytes(JSVAL_TO_STRING(*vp));
+
+							setCurrentMixerFromString(mixer);
+							break;
+						}
                         default : printf("UNKNOWN AUDIO PROP\n");
                         return JS_FALSE;
                 }
@@ -373,7 +408,7 @@ JSBool ADM_JSAvidemuxAudio::Codec(JSContext *cx, JSObject *obj, uintN argc,
         if(JSVAL_IS_STRING(argv[0]) == false || JSVAL_IS_INT(argv[1]) == false || JSVAL_IS_INT(argv[2]) == false  ||  JSVAL_IS_STRING(argv[3]) == false  )
                 return JS_FALSE;
         char *name = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
-        LowerCase(name);
+        ADM_LowerCase(name);
         enterLock();
         // First search the codec by its name
         if(!audioCodecSetByName(name))
@@ -404,25 +439,7 @@ JSBool ADM_JSAvidemuxAudio::Codec(JSContext *cx, JSObject *obj, uintN argc,
         leaveLock();
         return JS_TRUE;
 }// end Codec
-JSBool ADM_JSAvidemuxAudio::getNbTracks(JSContext *cx, JSObject *obj, uintN argc, 
-                                      jsval *argv, jsval *rval)
-{
-uint32_t nb=0;
-audioInfo *infos=NULL;
-        // default return value
-        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
-        if(argc != 0)
-                return JS_FALSE;
-        // default return value
-      
-        enterLock();
-        video_body->getAudioStreamsInfo(0,&nb, &infos);
-        leaveLock();
-        if(infos)
-                delete [] infos;
-        *rval = INT_TO_JSVAL(nb);
-        return JS_TRUE;
-}// end Codec
+
 JSBool ADM_JSAvidemuxAudio::setTrack(JSContext *cx, JSObject *obj, uintN argc, 
                                       jsval *argv, jsval *rval)
 {
@@ -445,6 +462,7 @@ audioInfo *infos=NULL;
         leaveLock();
         return JS_TRUE;
 }// end Codec
+
 JSBool ADM_JSAvidemuxAudio::secondAudioTrack(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
 {
         ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
@@ -454,10 +472,10 @@ JSBool ADM_JSAvidemuxAudio::secondAudioTrack(JSContext *cx, JSObject *obj, uintN
                 return JS_FALSE;
         // First arg is MP3 etc...
         char *name = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
-        LowerCase(name);
+        ADM_LowerCase(name);
         // First search the codec by its name
         AudioSource source;
-        if(AudioInvalid==(source=audioCodecGetFromName(name)))
+        if(AudioInvalid==(source=audioSourceFromString(name)))
                 return JS_FALSE;
         // Now get the name
         name = JS_GetStringBytes(JSVAL_TO_STRING(argv[1]));
@@ -470,74 +488,3 @@ JSBool ADM_JSAvidemuxAudio::secondAudioTrack(JSContext *cx, JSObject *obj, uintN
         leaveLock();
       return JS_FALSE;
 }
-JSBool ADM_JSAvidemuxAudio::mixer(JSContext *cx, JSObject *obj, uintN argc, 
-                                      jsval *argv, jsval *rval)
-{
-uint32_t nb=0,nw=0;
-uint32_t *infos=NULL;
-        // default return value
-        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
-
-        // default return value
-      if(argc != 1)
-                return JS_FALSE;
-        char *pArg0 = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
-        enterLock();
-
-        if(setCurrentMixerFromString(pArg0))
-                *rval=BOOLEAN_TO_JSVAL(true);
-        else
-                *rval=BOOLEAN_TO_JSVAL(false);
-        leaveLock();
-        return JS_TRUE;
-
-}// end Codec
-
-JSBool ADM_JSAvidemuxAudio::getNbChannels(JSContext *cx, JSObject *obj, uintN argc, 
-                                      jsval *argv, jsval *rval)
-{
-uint32_t nb=0, nw=0;
-audioInfo *infos=NULL;
-        // default return value
-        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
-        if(argc != 1)
-                return JS_FALSE;
-        // default return value
-      
-        if(JSVAL_IS_INT(argv[0]) == false)
-                return JS_FALSE;
-        enterLock();
-        video_body->getAudioStreamsInfo(0,&nb, &infos);
-        leaveLock()
-        nw=(JSVAL_TO_INT(argv[0]));
-        if(nw>nb)
-                return JS_FALSE;
-        *rval = INT_TO_JSVAL(infos[nw].channels);
-        delete [] infos;
-        return JS_TRUE;
-}// end Codec
-
-JSBool ADM_JSAvidemuxAudio::getBitrate(JSContext *cx, JSObject *obj, uintN argc, 
-                                      jsval *argv, jsval *rval)
-{
-uint32_t nb=0, nw=0;
-audioInfo *infos=NULL;
-        // default return value
-        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
-        if(argc != 1)
-                return JS_FALSE;
-        // default return value
-      
-        if(JSVAL_IS_INT(argv[0]) == false)
-                return JS_FALSE;
-        enterLock();
-        video_body->getAudioStreamsInfo(0,&nb, &infos);
-        leaveLock()
-        nw=(JSVAL_TO_INT(argv[0]));
-        if(nw>nb)
-                return JS_FALSE;
-        *rval = INT_TO_JSVAL(infos[nw].bitrate);
-        delete [] infos;
-        return JS_TRUE;
-}// end Codec
-
