@@ -10,66 +10,56 @@
 // Copyright: See COPYING file that comes with this distribution
 //
 //
-#include <config.h>
-#include <stdlib.h>
+#include "ADM_default.h"
 #include "ADM_JSAvidemuxVideo.h"
 #include "ADM_JSGlobal.h"
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
-#include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "avi_vars.h"
-#include "gui_action.hxx"
 #include "ADM_encoder/ADM_vidEncode.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_encoder/adm_encoder.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 #include "ADM_encoder/adm_encConfig.h"
-#include "ADM_editor/ADM_outputfmt.h"
 #include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
-#include "ADM_filter/video_filters.h"
+#include "ADM_JSAppliedVideoFilter.h"
 
-#include "ADM_script/ADM_container.h"
-
-//extern uint8_t indexMpeg(char *mpeg,char *file,uint8_t aid);
+extern VF_FILTERS filterGetTagFromName(const char *inname);
 extern uint8_t A_ListAllBlackFrames( char *file );
 extern uint8_t loadVideoCodecConfString( const char *name);
 extern uint8_t ADM_saveRaw (const char *name);
 extern int A_saveJpg (char *name);
 extern uint8_t loadVideoCodecConf( const char *name);
-extern int videoCodecConfigure(char *p,uint32_t i, uint8_t  *c);
-
 extern void filterCleanUp( void );
+extern uint32_t nb_active_filter;
 
-
-JSPropertySpec ADM_JSAvidemuxVideo::avidemuxvideo_properties[] = 
+JSPropertySpec ADM_JSAvidemuxVideo::properties[] = 
 { 
-        { "process", videoprocess_prop, JSPROP_ENUMERATE },        // process video when saving
+	{ "process", videoProcessProperty, JSPROP_ENUMERATE },        // process video when saving
+	{ "width", widthProperty, JSPROP_ENUMERATE },
+	{ "height", heightProperty, JSPROP_ENUMERATE },
+	{ "frameCount", frameCountProperty, JSPROP_ENUMERATE },
+	{ "vopPacked", vopPackedProperty, JSPROP_ENUMERATE },
+	{ "qPel", qPelProperty, JSPROP_ENUMERATE },
+	{ "gmc", gmcProperty, JSPROP_ENUMERATE },
+	{ "fcc", fccProperty, JSPROP_ENUMERATE },
+	{ "fps1000", fps1000Property, JSPROP_ENUMERATE },
+	{ "appliedFilters", appliedFiltersProperty, JSPROP_ENUMERATE },
 	{ 0 }
 };
 
-JSFunctionSpec ADM_JSAvidemuxVideo::avidemuxvideo_methods[] = 
+JSFunctionSpec ADM_JSAvidemuxVideo::methods[] = 
 {
 	{ "clear", Clear, 0, 0, 0 },	// clear
 	{ "add", Add, 3, 0, 0 },	// add
-        { "clearFilters", ClearFilters, 0, 0, 0 }, // Delete all filters
+	{ "clearFilters", ClearFilters, 0, 0, 0 }, // Delete all filters
 	{ "addFilter", AddFilter, 10, 0, 0 },	// Add filter to filter chain
 	{ "codec", Codec, 3, 0, 0 },	// Set the video codec
+	{ "codecPlugin", CodecPlugin, 4, 0, 0 },	// Set the video codec plugin
 	{ "codecConf", CodecConf, 1, 0, 0 },	// load video codec config
 	{ "save", Save, 1, 0, 0 },	// save video portion of the stream
 	{ "saveJpeg", SaveJPEG, 1, 0, 0 },	// save the current frame as a JPEG
 	{ "listBlackFrames", ListBlackFrames, 1, 0, 0 },	// output a list of the black frame to a file
 	{ "setPostProc", PostProcess, 3, 0, 0 },	// Postprocess
-        { "setFps1000", SetFps1000, 1, 0, 0 },        // Postprocess
-        { "getFps1000", GetFps1000, 0, 0, 0 },        // Postprocess
-        { "getNbFrames", GetNbFrames, 0, 0, 0 },        // Postprocess
-        { "getWidth", GetWidth, 0, 0, 0 },        // Postprocess
-        { "getHeight", GetHeight, 0, 0, 0 },        // Postprocess
-        { "getFCC", GetFCC, 0, 0, 0 },        // Postprocess
-        { "isVopPacked", isVopPacked, 0, 0, 0 },        // Postprocess
-        { "hasQpel", hasQpel, 0, 0, 0 },        // Postprocess
-        { "hasGmc", hasGmc, 0, 0, 0 },        // Postprocess
-        { "frameSize", getFrameSize, 1, 0, 0 },        // FrameSize
-        { "frameType", getFrameType, 1, 0, 0 },        // Postprocess
+	{ "getFrameSize", getFrameSize, 1, 0, 0 },        // FrameSize
+	{ "getFrameType", getFrameType, 1, 0, 0 },        // Postprocess
 	{ 0 }
 };
 
@@ -101,25 +91,14 @@ ADM_AvidemuxVideo *ADM_JSAvidemuxVideo::getObject()
 
 JSObject *ADM_JSAvidemuxVideo::JSInit(JSContext *cx, JSObject *obj, JSObject *proto)
 {
-        JSObject *newObj = JS_InitClass(cx, obj, proto, &m_classAvidemuxVideo, 
-                                        ADM_JSAvidemuxVideo::JSConstructor, 0,
-                                        ADM_JSAvidemuxVideo::avidemuxvideo_properties, ADM_JSAvidemuxVideo::avidemuxvideo_methods,
-                                        NULL, NULL);
-	return newObj;
-}
+	JSObject *newObj = JS_InitClass(cx, obj, proto, &m_classAvidemuxVideo, NULL, 0,
+		ADM_JSAvidemuxVideo::properties, ADM_JSAvidemuxVideo::methods, NULL, NULL);
+	ADM_JSAvidemuxVideo *p = new ADM_JSAvidemuxVideo();
 
-JSBool ADM_JSAvidemuxVideo::JSConstructor(JSContext *cx, JSObject *obj, uintN argc, 
-								 jsval *argv, jsval *rval)
-{
-        if(argc != 0)
-                return JS_FALSE;
-        ADM_JSAvidemuxVideo *p = new ADM_JSAvidemuxVideo();
-        ADM_AvidemuxVideo *pObject = new ADM_AvidemuxVideo();
-        p->setObject(pObject);
-        if ( ! JS_SetPrivate(cx, obj, p) )
-                return JS_FALSE;
-        *rval = OBJECT_TO_JSVAL(obj);
-        return JS_TRUE;
+	p->setObject(new ADM_AvidemuxVideo());
+	JS_SetPrivate(cx, newObj, p);
+
+	return newObj;
 }
 
 void ADM_JSAvidemuxVideo::JSDestructor(JSContext *cx, JSObject *obj)
@@ -132,35 +111,127 @@ void ADM_JSAvidemuxVideo::JSDestructor(JSContext *cx, JSObject *obj)
 
 JSBool ADM_JSAvidemuxVideo::JSGetProperty(JSContext *cx, JSObject *obj, jsval id, jsval *vp)
 {
-        if (JSVAL_IS_INT(id)) 
-        {
-                ADM_JSAvidemuxVideo *priv = (ADM_JSAvidemuxVideo *) JS_GetPrivate(cx, obj);
-                switch(JSVAL_TO_INT(id))
-                {
-                        case videoprocess_prop:
-                                *vp = BOOLEAN_TO_JSVAL(priv->getObject()->m_bVideoProcess);
-                                break;
-                }
-        }
-        return JS_TRUE;
+	if (JSVAL_IS_INT(id)) 
+	{
+		ADM_JSAvidemuxVideo *priv = (ADM_JSAvidemuxVideo *) JS_GetPrivate(cx, obj);
+		switch(JSVAL_TO_INT(id))
+		{
+			case videoProcessProperty:
+				*vp = BOOLEAN_TO_JSVAL(priv->getObject()->m_bVideoProcess);
+				break;
+			case widthProperty:
+			{
+				aviInfo info;
+
+				video_body->getVideoInfo(&info);
+				*vp = INT_TO_JSVAL(info.width);
+				break;
+			}
+			case heightProperty:
+			{
+				aviInfo info;
+
+				video_body->getVideoInfo(&info);
+				*vp = INT_TO_JSVAL(info.height);
+				break;
+			}
+			case frameCountProperty:
+			{
+				aviInfo info;
+
+				video_body->getVideoInfo(&info);
+				*vp = INT_TO_JSVAL(info.nb_frames);
+				break;
+			}
+			case vopPackedProperty:
+			{
+				*vp = ((video_body->getSpecificMpeg4Info() & ADM_VOP_ON) == ADM_VOP_ON);
+				break;
+			}
+			case qPelProperty:
+			{
+				*vp = ((video_body->getSpecificMpeg4Info() & ADM_QPEL_ON) == ADM_QPEL_ON);
+				break;
+			}
+			case gmcProperty:
+			{
+				*vp = ((video_body->getSpecificMpeg4Info() & ADM_GMC_ON) == ADM_GMC_ON);
+				break;
+			}
+			case fccProperty:
+			{
+				aviInfo info;
+
+				video_body->getVideoInfo(&info);
+				*vp = STRING_TO_JSVAL(JS_NewStringCopyZ(cx, fourCC::tostring(info.fcc)));
+				break;
+			}
+			case fps1000Property:
+			{
+				aviInfo info;
+
+				video_body->getVideoInfo(&info);
+				*vp = INT_TO_JSVAL(info.fps1000);
+				break;
+			}
+			case appliedFiltersProperty:
+			{
+				JSObject *filters = JS_NewArrayObject(cx, 0, NULL);
+				jsval appliedFilter;
+
+				*vp = OBJECT_TO_JSVAL(filters);
+
+				for (int filterIndex = 1; filterIndex < nb_active_filter; filterIndex++)
+				{
+					appliedFilter = OBJECT_TO_JSVAL(ADM_JSAppliedVideoFilter::JSInit(cx, obj, NULL, filterIndex));
+					JS_SetElement(cx, filters, filterIndex - 1, &appliedFilter);
+				}
+
+				break;
+			}
+		}
+	}
+	return JS_TRUE;
 }
 
 JSBool ADM_JSAvidemuxVideo::JSSetProperty(JSContext *cx, JSObject *obj, jsval id, jsval *vp)
 {
-        if (JSVAL_IS_INT(id)) 
-        {
-                ADM_JSAvidemuxVideo *priv = (ADM_JSAvidemuxVideo *) JS_GetPrivate(cx, obj);
-                switch(JSVAL_TO_INT(id))
-                {
-                        case videoprocess_prop:
-                                if(JSVAL_IS_BOOLEAN(*vp) == false)
-                                        break;
-                                priv->getObject()->m_bVideoProcess = JSVAL_TO_BOOLEAN(*vp);
-                                UI_setVProcessToggleStatus(priv->getObject()->m_bVideoProcess);
-                                break;
-                }
-        }
-        return JS_TRUE;
+	if (JSVAL_IS_INT(id)) 
+	{
+		ADM_JSAvidemuxVideo *priv = (ADM_JSAvidemuxVideo *) JS_GetPrivate(cx, obj);
+		switch(JSVAL_TO_INT(id))
+		{
+			case videoProcessProperty:
+				if (!JSVAL_IS_BOOLEAN(*vp))
+					break;
+
+				priv->getObject()->m_bVideoProcess = JSVAL_TO_BOOLEAN(*vp);
+				UI_setVProcessToggleStatus(priv->getObject()->m_bVideoProcess);
+				break;
+			case fps1000Property:
+			{
+				if(!JSVAL_IS_INT(*vp))
+					break;
+
+				aviInfo info;
+				int fps = JSVAL_TO_INT(*vp);
+
+				if(fps > 100000 || fps < 2000)
+				{
+					printf("FPS too low\n");
+					break;
+				}
+
+				video_body->getVideoInfo(&info);
+				info.fps1000 = fps;
+				video_body->updateVideoInfo(&info);
+
+				break;
+			}
+		}
+	}
+
+	return JS_TRUE;
 }
 
 JSBool ADM_JSAvidemuxVideo::Clear(JSContext *cx, JSObject *obj, uintN argc, 
@@ -286,21 +357,61 @@ JSBool ADM_JSAvidemuxVideo::Codec(JSContext *cx, JSObject *obj, uintN argc,
         return JS_TRUE;
 }// end Codec
 
+JSBool ADM_JSAvidemuxVideo::CodecPlugin(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
+{
+	*rval = BOOLEAN_TO_JSVAL(false);
+
+	if (argc != 4)
+		return JS_FALSE;
+
+	printf("Codec Plugin ... \n");
+
+	if (!JSVAL_IS_STRING(argv[0]) || !JSVAL_IS_STRING(argv[1]) || !JSVAL_IS_STRING(argv[2]) || !JSVAL_IS_STRING(argv[3]))
+		return JS_FALSE;
+
+	char *guid = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
+	char *desc = JS_GetStringBytes(JSVAL_TO_STRING(argv[1]));
+	char *conf = JS_GetStringBytes(JSVAL_TO_STRING(argv[2]));
+	char *data = JS_GetStringBytes(JSVAL_TO_STRING(argv[3]));
+
+	printf("[guid] %s\n", guid);
+	printf("[desc] %s\n", desc);
+	printf("[conf] %s\n", conf);
+	printf("[data] %s\n", data);
+
+	enterLock();
+
+	if (!videoCodecPluginSelectByGuid(guid))
+		*rval = BOOLEAN_TO_JSVAL(false);
+	else
+		*rval = BOOLEAN_TO_JSVAL(videoCodecConfigure(conf, 0, (uint8_t*)data));
+
+	leaveLock();
+
+	return JS_TRUE;
+}
+
 JSBool ADM_JSAvidemuxVideo::CodecConf(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
-{// begin CodecConf
-        *rval = BOOLEAN_TO_JSVAL(false);
-        if(argc != 1)
-                return JS_FALSE;
-        if(JSVAL_IS_STRING(argv[0]) == false)
-                return JS_FALSE;
-        char *pTempStr = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
-        printf("Codec Conf Video \"%s\"\n",pTempStr);
-        enterLock();
-        *rval = INT_TO_JSVAL(loadVideoCodecConf(pTempStr));
-        leaveLock();
-        return JS_TRUE;
-}// end CodecConf
+{
+	*rval = BOOLEAN_TO_JSVAL(false);
+
+	if (argc != 1)
+		return JS_FALSE;
+
+	if (!JSVAL_IS_STRING(argv[0]))
+		return JS_FALSE;
+
+	char *pTempStr = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
+
+	printf("Codec Conf Video \"%s\"\n", pTempStr);
+
+	enterLock();
+	*rval = INT_TO_JSVAL(loadVideoCodecConf(pTempStr));
+	leaveLock();
+
+	return JS_TRUE;
+}
 
 JSBool ADM_JSAvidemuxVideo::Save(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
@@ -372,166 +483,9 @@ JSBool ADM_JSAvidemuxVideo::PostProcess(JSContext *cx, JSObject *obj, uintN argc
         return JS_TRUE;
 }// end PostProcess
 
-JSBool ADM_JSAvidemuxVideo::GetFps1000(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-aviInfo info;
-        if(argc != 0)
-          return JS_FALSE;
-        
-        enterLock();
-        video_body->getVideoInfo(&info);
-        leaveLock();
-        
-        *rval = INT_TO_JSVAL(info.fps1000);
-        return JS_TRUE;
-}// end PostProcess
-JSBool ADM_JSAvidemuxVideo::GetNbFrames(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-aviInfo info;
-        if(argc != 0)
-          return JS_FALSE;
-        
-        enterLock();
-        video_body->getVideoInfo(&info);
-        leaveLock();
-        
-        *rval = INT_TO_JSVAL(info.nb_frames);
-        return JS_TRUE;
-}// end PostProcess
-
-JSBool ADM_JSAvidemuxVideo::SetFps1000(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-int fps;
-aviInfo info;
-
-        if(argc != 1)
-          return JS_FALSE;
-        if(JSVAL_IS_INT(argv[0]) == false)
-          return JS_FALSE;
-
-        enterLock();
-        video_body->getVideoInfo(&info);
-        video_body->getVideoInfo (avifileinfo);
-
-
-        // default return value
-        fps=JSVAL_TO_INT(argv[0]);
-        if(fps>100000 || fps<2000)
-        {      
-                printf("Fps too low\n");
-                leaveLock();
-                return JS_FALSE;
-        }       
- 	
-       info.fps1000=fps;
-        video_body->updateVideoInfo(&info);
-        video_body->getVideoInfo (avifileinfo);
-        
-	leaveLock();
-        return JS_TRUE;
-}// end PostProcess
-
-
-JSBool ADM_JSAvidemuxVideo::GetWidth(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-aviInfo info;
-        if(argc != 0)
-          return JS_FALSE;
-
-
-        enterLock();
-        video_body->getVideoInfo(&info);
-        leaveLock();
-        
-        *rval = INT_TO_JSVAL(info.width);
-        return JS_TRUE;
-}// end PostProcess
-JSBool ADM_JSAvidemuxVideo::GetHeight(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-aviInfo info;
-        if(argc != 0)
-          return JS_FALSE;
-
-        enterLock();
-        video_body->getVideoInfo(&info);
-        leaveLock();
-        
-        *rval = INT_TO_JSVAL(info.height);
-        return JS_TRUE;
-}// end PostProcess
-JSBool ADM_JSAvidemuxVideo::GetFCC(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-aviInfo info;
-
-        if(argc != 0)
-          return JS_FALSE;
-
-        enterLock();
-        video_body->getVideoInfo(&info);
-        leaveLock();
-        
-        *rval = STRING_TO_JSVAL(JS_NewStringCopyZ(cx, fourCC::tostring(info.fcc)));
-        return JS_TRUE;
-}// end PostProcess
-
-JSBool ADM_JSAvidemuxVideo::isVopPacked(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-int32_t info;
-        if(argc != 0)
-          return JS_FALSE;
-
-      enterLock();
-       info=video_body->getSpecificMpeg4Info();
-       leaveLock();
-         
-        // default return value
-        *rval=JS_FALSE;
-        if(info & ADM_VOP_ON) *rval=JS_TRUE;
-        return JS_TRUE;
-}// end PostProcess
-JSBool ADM_JSAvidemuxVideo::hasGmc(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-uint32_t info;
-        if(argc != 0)
-          return JS_FALSE;
-
-       enterLock();
-       info=video_body->getSpecificMpeg4Info();
-       leaveLock(); 
-        
-        // default return value
-        *rval=JS_FALSE;
-        if(info & ADM_GMC_ON) *rval=JS_TRUE;
-        return JS_TRUE;
-}// end PostProcess
-JSBool ADM_JSAvidemuxVideo::hasQpel(JSContext *cx, JSObject *obj, uintN argc, 
-                                       jsval *argv, jsval *rval)
-{// begin PostProcess
-uint32_t info;
-        if(argc != 0)
-          return JS_FALSE;
-        
-        enterLock();
-        info=video_body->getSpecificMpeg4Info();
-        leaveLock(); 
-        
-        *rval=JS_FALSE;
-        if(info & ADM_QPEL_ON) *rval=JS_TRUE;
-        return JS_TRUE;
-}// end PostProcess
-
-
 JSBool ADM_JSAvidemuxVideo::getFrameSize(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
-{// begin PostProcess
+{
 uint32_t info;
 uint32_t frame;
 uint32_t sz;
@@ -545,10 +499,11 @@ uint32_t sz;
         
         *rval=INT_TO_JSVAL(sz);
         return JS_TRUE;
-}// end PostProcess
+}
+
 JSBool ADM_JSAvidemuxVideo::getFrameType(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
-{// begin PostProcess
+{
 uint32_t info;
 uint32_t frame;
 uint32_t sz;
@@ -562,5 +517,5 @@ uint32_t sz;
         
         *rval=INT_TO_JSVAL(sz);
         return JS_TRUE;
-}// end PostProcess
+}
 /* EOF */
