@@ -2,10 +2,12 @@
 #define _ADM_JSDIRECTORYSEARCH_H
 
 #pragma once
-#include <config.h>
+
+#include "config.h"
 
 // Spidermonkey
-#include <jsapi.h>
+#include "jsapi.h"
+#include <string.h>
 #include "DirectorySearch.h"
 
 class ADM_JSDirectorySearch
