@@ -26,7 +26,10 @@ const ADM_CONTAINER container[]=
   MK_CONT(AVI_DUAL),
   MK_CONT(AVI_UNP),
   MK_CONT(MP4),
-  MK_CONT(FMT_DUMMY)  
+  MK_CONT(PSP),
+  MK_CONT(FLV),
+  MK_CONT(DUMMY),
+  MK_CONT(MATROSKA)  
 };
 #define NB_CONT (sizeof(container)/sizeof(ADM_CONTAINER))
 #endif
