@@ -6,14 +6,14 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
- 
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
-#include "ADM_utilities/default.h"
-#include "ADM_osSupport/ADM_threads.h"
+
+#include "ADM_default.h"
+#include "ADM_threads.h"
+
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 
