@@ -18,16 +18,11 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
-#include <math.h>
 
 
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "ADM_default.h"
+
+
 
 #include "DIA_busy.h"
 
