@@ -1,16 +1,12 @@
-# include <config.h>
+# include "config.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
 #include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
+
 #include "prefs.h"
 
-#include "ADM_toolkit/toolkit.hxx"
+
 
 #include "ADM_assert.h" 
 #include "DIA_idx_pg.h"
