@@ -8,18 +8,18 @@
 //
 //
 
-#include <config.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "config.h"
+#include "ADM_default.h"
+#include "ADM_misc.h"
+
 #include "GUI_ui.h"
-#include "ADM_colorspace/ADM_rgb.h"
+#include "ADM_colorspace.h"
+
 static ADM_OUT_FORMAT format=ADM_AVI;
 static int audioCodec=0;
 static int videoCodec=0;
- ColYuvRgb rgbConverter(640,480);
- ColYuvRgb rgbConverter2(640,480);
+ 
+
 //**************************************************
 int 	UI_getCurrentACodec(void)
 {
@@ -131,6 +131,10 @@ uint8_t UI_updateRecentMenu( void )
   return 1;
 }
 
+void UI_updateRecentProjectsMenu(void)
+{
+}
+
 uint8_t UI_arrow_enabled(void)
 {
   return 1;
