@@ -7,13 +7,12 @@
 #include <time.h>
 #include <sys/time.h>
 
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include "fourcc.h"
-#include "avio.hxx"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 
-#include "GUI_render.h"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
 
 void UI_rgbDraw(void *widg,uint32_t w, uint32_t h,uint8_t *ptr) {}
 void UI_updateDrawWindowSize(void *win,uint32_t w,uint32_t h) {}
