@@ -17,23 +17,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdio.h>
-#include <math.h>
-
-
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-
 #include "DIA_busy.h"
-
+#include "ADM_toolkitQt.h"
 
 void DIA_StartBusy( void )
 {
@@ -47,6 +32,7 @@ void DIA_StopBusy( void )
 
 void DIA_StartBusyDialog( void )
 {
+	UI_purge();
 }
 
 void DIA_StopBusyDialog( void )
@@ -55,4 +41,5 @@ void DIA_StopBusyDialog( void )
 
 void DIA_runBusy( void )
 {
+	UI_purge();
 }
