@@ -16,42 +16,15 @@
  ***************************************************************************/
 #include <math.h>
 
-#include "ui_calculator.h"
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "Q_calculator.h"
 
 #include "avi_vars.h"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
+#include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
-#include "ADM_filter/video_filters.h"
+#include "ADM_video/ADM_vidMisc.h"
 #include "ADM_encoder/adm_encConfig.h"
-#include "../ADM_toolkit/qtToolkit.h"
-
-class calculatorDialog : public QDialog
-{
-	Q_OBJECT
-
-private:
-	Ui_CalculatorDialog ui;
-	unsigned int _videoFrameCount;
-	unsigned int _videoDuration;
-
-	void update(void);
-	unsigned int getPictureSize(void);
-
-public:
-	calculatorDialog(QWidget *parent);
-	~calculatorDialog();
-
-	unsigned int videoSize(void);
-	unsigned int videoBitrate(void);
-
-private slots:
-	void comboBox_currentIndexChanged(int index);
-	void mediumComboBox_currentIndexChanged(int index);
-	void spinBox_valueChanged(int value);
-};
+#include "ADM_toolkitQt.h"
 
 calculatorDialog::calculatorDialog(QWidget *parent) : QDialog(parent)
 {
