@@ -11,111 +11,31 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-
 #include <QtGui/QPushButton>
+#include <QtGui/QCloseEvent>
 
-#define Ui_Dialog Ui_encodingDialog
-#include "ui_encoding.h"
-#undef Ui_Dialog 
-
-#include "default.h"
+#include "Q_encoding.h"
 #include "prefs.h"
-#include "ADM_assert.h"
-#include "ADM_osSupport/ADM_misc.h"
 #include "DIA_working.h"
 #include "DIA_encoding.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 #include "ADM_libraries/ADM_utilities/avidemutils.h"
-#include "ADM_gui/ADM_qtray.h"
-#include "../ADM_toolkit/qtToolkit.h"
+#include "ADM_video/ADM_vidMisc.h"
+#include "../ADM_gui/ADM_qtray.h"
+#include "ADM_toolkitQt.h"
 
 extern void UI_iconify(void);
 extern void UI_deiconify(void);
 extern void UI_purge(void);
 static int stopReq=0;
-class encodingWindow : public QDialog
-{
-     Q_OBJECT
-
- public:
-     encodingWindow(QWidget *parent, bool useTray);
-     Ui_encodingDialog ui;
-
- protected:
-	 void changeEvent(QEvent *event)
-	 {
-		 if (event->type() == QEvent::WindowStateChange)
-		 {
-			 QDialog *parent = (QDialog*)this->parent();
-
-			 if (isMinimized())
-			 {
-				 if (useTray)
-				 {
-					 hide();
-					 UI_iconify();
-				 }
-				 else
-					 parent->showMinimized();
-			 }
-			 else
-			 {
-				 showNormal();
-				 parent->showNormal();
-			 }
-		 }
-	 };
-
- private:
-	 bool useTray;
-
- public slots:
-	void buttonPressed(void ) { printf("StopReq\n");stopReq=1;}
-
-	void priorityChanged(int priorityLevel)
-	{
-	#ifndef ADM_WIN32
-		if (getuid() != 0)
-		{
-			ui.comboBoxPriority->disconnect(SIGNAL(currentIndexChanged(int)));
-			ui.comboBoxPriority->setCurrentIndex(2);
-			connect(ui.checkBoxShutdown, SIGNAL(currentIndexChanged(int)), this, SLOT(priorityChanged(int)));
-
-			GUI_Error_HIG(QT_TR_NOOP("Privileges Required"), QT_TR_NOOP( "Root privileges are required to perform this operation."));
-
-			return;
-		}
-	#endif
-
-		setpriority(PRIO_PROCESS, 0, ADM_getNiceValue(priorityLevel));
-	}
-
-	void shutdownChanged(int state)
-	{
-	#ifndef ADM_WIN32
-		if (getuid() != 0)
-		{
-			ui.checkBoxShutdown->disconnect(SIGNAL(stateChanged(int)));
-			ui.checkBoxShutdown->setCheckState(Qt::Unchecked);
-			connect(ui.checkBoxShutdown, SIGNAL(stateChanged(int)), this, SLOT(shutdownChanged(int)));
-
-			GUI_Error_HIG(QT_TR_NOOP("Privileges Required"), QT_TR_NOOP( "Root privileges are required to perform this operation."));
-		}
-	#endif
-	}
-};
-
 
 encodingWindow::encodingWindow(QWidget *parent, bool useTray) : QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowMinimizeButtonHint)
- {
+{
 	this->useTray = useTray;
 	ui.setupUi(this);
 
-#ifndef ADM_WIN32
+#ifndef __WIN32
 	//check for root privileges
 	if (getuid() == 0)
 	{
@@ -124,7 +44,7 @@ encodingWindow::encodingWindow(QWidget *parent, bool useTray) : QDialog(parent,
 	}
 #endif
 
-	ui.buttonBox->button(QDialogButtonBox::Cancel)->setText(QString::fromUtf8(QT_TR_NOOP("Pause / Abort")));
+	ui.buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Pause / Abort"));
 
 	connect(ui.checkBoxShutdown, SIGNAL(stateChanged(int)), this, SLOT(shutdownChanged(int)));
 	connect(ui.buttonBox, SIGNAL(rejected()), this, SLOT(buttonPressed()));
@@ -135,7 +55,7 @@ encodingWindow::encodingWindow(QWidget *parent, bool useTray) : QDialog(parent,
 
 	prefs->get(PRIORITY_ENCODING,&priority);	
 
-#ifndef ADM_WIN32
+#ifndef __WIN32
 	// check for root privileges
 	if (getuid() == 0)
 	{
@@ -145,6 +65,83 @@ encodingWindow::encodingWindow(QWidget *parent, bool useTray) : QDialog(parent,
 	ui.comboBoxPriority->setCurrentIndex(priority);
 #endif
  }
+
+void encodingWindow::changeEvent(QEvent *event)
+{
+	if (event->type() == QEvent::WindowStateChange)
+	{
+		QDialog *parent = (QDialog*)this->parent();
+
+		if (isMinimized())
+		{
+			if (useTray)
+			{
+				hide();
+				UI_iconify();
+			}
+			else
+				parent->showMinimized();
+		}
+		else
+		{
+			showNormal();
+			parent->showNormal();
+		}
+	}
+}
+
+void encodingWindow::closeEvent(QCloseEvent *event)
+{
+	if (GUI_Alternate((char*)encodingWindow::tr("The encoding is paused. Do you want to resume or abort?").toUtf8().constData(),
+		(char*)encodingWindow::tr("Resume").toUtf8().constData(), (char*)encodingWindow::tr("Abort").toUtf8().constData()))
+	{
+		stopReq = 0;
+		event->ignore();
+	}
+	else
+	{
+		stopReq = 1;
+		event->accept();
+	}
+}
+
+void encodingWindow::buttonPressed(void)
+{
+	this->close();
+}
+
+void encodingWindow::priorityChanged(int priorityLevel)
+{
+#ifndef __WIN32
+	if (getuid() != 0)
+	{
+		ui.comboBoxPriority->disconnect(SIGNAL(currentIndexChanged(int)));
+		ui.comboBoxPriority->setCurrentIndex(2);
+		connect(ui.checkBoxShutdown, SIGNAL(currentIndexChanged(int)), this, SLOT(priorityChanged(int)));
+
+		GUI_Error_HIG(tr("Privileges Required").toUtf8().constData(), tr("Root privileges are required to perform this operation.").toUtf8().constData());
+
+		return;
+	}
+#endif
+
+	setpriority(PRIO_PROCESS, 0, ADM_getNiceValue(priorityLevel));
+}
+
+void encodingWindow::shutdownChanged(int state)
+{
+#ifndef __WIN32
+	if (getuid() != 0)
+	{
+		ui.checkBoxShutdown->disconnect(SIGNAL(stateChanged(int)));
+		ui.checkBoxShutdown->setCheckState(Qt::Unchecked);
+		connect(ui.checkBoxShutdown, SIGNAL(stateChanged(int)), this, SLOT(shutdownChanged(int)));
+
+		GUI_Error_HIG(tr("Privileges Required").toUtf8().constData(), tr("Root privileges are required to perform this operation.").toUtf8().constData());
+	}
+#endif
+}
+
 //*******************************************
 #define WIDGET(x) (window->ui.x)
 #define WRITEM(x,y) window->ui.x->setText(QString::fromUtf8(y))
@@ -223,7 +220,7 @@ DIA_encoding::~DIA_encoding( )
 
 	if (shutdownRequired && !stopReq)
 	{
-		DIA_working *work=new DIA_working(QT_TR_NOOP("Shutting down"));
+		DIA_working *work=new DIA_working(encodingWindow::tr("Shutting down").toUtf8().constData());
 		bool performShutdown=true;
 
 		for(int i = 0; i <= 30; i++)
@@ -511,20 +508,10 @@ void DIA_encoding::setAudioSize(uint32_t size)
 */
 uint8_t DIA_encoding::isAlive( void )
 {
-        updateUI();
+	if (!stopReq)
+		updateUI();
 
-        if(stopReq)
-        {
-          if(GUI_Alternate((char*)QT_TR_NOOP("The encoding is paused. Do you want to resume or abort?"),
-                              (char*)QT_TR_NOOP("Resume"),(char*)QT_TR_NOOP("Abort")))
-                 {
-                         stopReq=0;
-                 }
-        }
-
-        if(!stopReq) return 1;		
-
-        return 0;
+	return !stopReq;
 }
 
 //********************************************
