@@ -16,47 +16,14 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
-#include <string.h>
-#include <stdio.h>
-#include <math.h>
-
-#include "ui_vobsub.h"
-
-#include "default.h"
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/filesel.h"
-#include "ADM_image.h"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_colorspace/ADM_rgb.h"
-
-#include "ADM_videoFilter/ADM_vobsubinfo.h"
-#include "ADM_videoFilter/ADM_vidVobSub.h"
-
-#include "ADM_assert.h"
-#include "../ADM_toolkit/qtToolkit.h"
-
+#include "Q_vobsub.h"
+#include "DIA_fileSel.h"
+#include "ADM_toolkitQt.h"
 
 //
 //	Video is in YV12 Colorspace
 //
 //
-class Ui_vobsubWindow : public QDialog
- {
-     Q_OBJECT
- protected :
-	 vobSubParam *param;
-	 void  		 fillLanguage(const char *file);
- public:
-     Ui_vobsubWindow(QWidget *parent, vobSubParam *param);
-     ~Ui_vobsubWindow();
-     Ui_DialogVobSub ui;
-     
-     void  gather(void);
- 
-private slots:
-	void idxSel();
- };
 Ui_vobsubWindow::Ui_vobsubWindow(QWidget *parent, vobSubParam *parm) : QDialog(parent)
   {
     uint32_t width,height;
@@ -118,7 +85,7 @@ void Ui_vobsubWindow::idxSel()
 {
 	char fileIdx[1024];
 	
-	if(FileSel_SelectRead(QT_TR_NOOP("Select Idx File"),fileIdx,1023, NULL) && ADM_fileExist(fileIdx))
+	if(FileSel_SelectRead(tr("Select Idx File").toUtf8().constData(),fileIdx,1023, NULL) && ADM_fileExist(fileIdx))
 	{
 		// Set entry
 		ui.lineEditIdx->setText(fileIdx);
