@@ -12,12 +12,9 @@ Custom slider
 *                                                                         *
 ***************************************************************************/
 
-#include "config.h"
-
-#include <math.h>
-#include <QPainter>
-#include <QSlider>
-
+#include <QtGui/QPainter>
+#include <QtGui/QSlider>
+#include "ADM_default.h"
 #include "ADM_qslider.h"
 
 ADM_QSlider::ADM_QSlider(QWidget *parent) : QSlider(parent)
