@@ -12,6 +12,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
+#undef QT_TR_NOOP
 
 #include <QtCore/QUrl>
 #include <QtCore/QDir>
@@ -40,6 +41,7 @@ extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
 extern int automation(void );
 extern void HandleAction(Action a);
 extern bool isVideoCodecConfigurable(void);
+extern int encoderGetDefaultIndex(void);
 extern int encoderGetEncoderCount (void);
 extern const char *encoderGetIndexedName (uint32_t i);
 uint32_t audioEncoderGetNumberOfEncoders(void);
@@ -382,9 +384,10 @@ void MainWindow::timeChanged(int)
 void MainWindow::buttonPressed(void)
 {
 	// Receveid a key press Event, look into table..
-	const char *source=qPrintable(sender()->objectName());
-
-	Action action=searchTranslationTable(source);
+    QObject *obj=sender();
+    if(!obj) return;
+    QString me(obj->objectName());
+    Action action=searchTranslationTable(qPrintable(me));
 
 	if(action!=ACT_DUMMY)
 		HandleAction (action);
@@ -627,7 +630,7 @@ void MainWindow::addDirEntryToMenu(QMenu *parentMenu, QString path)
 
 				if (fileList[x].isDir())
 				{
-					menu = parentMenu->addMenu(QDir(fileList[x].filePath()).dirName());
+					menu = parentMenu->addMenu(tr(QDir(fileList[x].filePath()).dirName().toUtf8().constData()));
 
 					addDirEntryToMenu(menu, fileList[x].filePath() + QDir::separator());
 				}
@@ -638,7 +641,7 @@ void MainWindow::addDirEntryToMenu(QMenu *parentMenu, QString path)
 	}
 	else
 	{
-		QAction *action = new QAction(info.completeBaseName(), parentMenu);
+		QAction *action = new QAction(tr(info.completeBaseName().toUtf8().constData()), parentMenu);
 
 		parentMenu->addAction(action);
 		connect(action, SIGNAL(triggered()), this, SLOT(autoMenuHandler()));
@@ -876,6 +879,9 @@ void setupMenus(void)
 		WIDGET(comboBoxVideo)->addItem(name);
 	}
 
+	if (encoderGetDefaultIndex() > -1)
+		UI_setVideoCodec(encoderGetDefaultIndex());
+
 	// And A codec
 
 	uint32_t nbAud;
@@ -1012,9 +1018,8 @@ void UI_setFrameType( uint32_t frametype,uint32_t qp)
 	default:c='?';break;
 
 	}
-	sprintf(string,QT_TR_NOOP("%c (%02d)"),c,qp);
-	WIDGET(label_8)->setText(QString::fromUtf8(string));
 
+	WIDGET(label_8)->setText(MainWindow::tr("%1 (%2)").arg(c).arg(qp, 2, 10, QLatin1Char('0')));
 }
 
 /**
