@@ -15,27 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "ui_preview.h"
-
-#include "default.h"
-#include "ADM_assert.h"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "DIA_flyDialog.h"
-#include "DIA_flyPreview.h"
-#include "../ADM_dialog/DIA_flyDialogQt4.h"
-
-class Ui_previewWindow : public QDialog
-{
-	Q_OBJECT
-
-public:
-	ADM_QCanvas *canvas;
-	flyPreview *preview;
-	Ui_previewDialog ui;
-	Ui_previewWindow(QWidget *parent, int width, int height);
-	~Ui_previewWindow();
-	void update(uint8_t *buffer);
-};
+#include "Q_preview.h"
 
 Ui_previewWindow::Ui_previewWindow(QWidget *parent, int width, int height) : QDialog(parent)
 {
