@@ -17,12 +17,8 @@
 
 #include "ui_preview.h"
 
-#include "default.h"
-#include "ADM_assert.h"
-#include "ADM_video/ADM_genvideo.hxx"
 #include "DIA_flyDialog.h"
-#include "DIA_flyPreview.h"
-#include "../ADM_dialog/DIA_flyDialogQt4.h"
+#include "../ADM_dialog/DIA_flyPreview.h"
 
 class Ui_previewWindow : public QDialog
 {
