@@ -1,5 +1,6 @@
-#include "default.h"
-#include "ADM_commonUI/DIA_factory.h"
+#include "config.h"
+#include "ADM_inttype.h"
+#include "DIA_factory.h"
 
 uint8_t DIA_job_select(char **jobname, char **filename)
 {
