@@ -12,8 +12,9 @@
 //
 //
 
-#include "default.h"
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "config.h"
+#include "ADM_default.h"
+#include "DIA_factory.h"
 
 /**
       \fn DIA_lavDecoder
