@@ -17,27 +17,23 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <config.h>
+#include "config.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
 
-#include "default.h"
+#include "ADM_default.h"
 
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "DIA_factory.h"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter.h"
+
 
 #include "ADM_videoFilter/ADM_vobsubinfo.h"
 #include "ADM_videoFilter/ADM_vidVobSub.h"
 #include "ADM_ocr/ADM_ocr.h"
-#include "ADM_osSupport/ADM_misc.h"
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 #include "prefs.h"
-#include "ADM_assert.h"
+
 
 #include "ADM_ocr/ADM_ocr.h"
 
@@ -83,7 +79,7 @@ uint8_t DIA_ocrGen(void)
 _again:  
   // Fist build a dialogFactory to get input and output files
   diaElemButton   selectIdx(QT_TR_NOOP("Select idx file:"), cb_idx,&subparam,NULL);
-  diaElemFile     selectGlyph(1,&glyphFileName,QT_TR_NOOP("Use GlyphSet (optional):"), NULL, QT_TR_NOOP("Select GlyphSet file"));
+  diaElemFile     selectGlyph(0,&glyphFileName,QT_TR_NOOP("Use GlyphSet (optional):"), NULL, QT_TR_NOOP("Select GlyphSet file"));
   diaElemFile     selectSrt(1,&srtFileName,QT_TR_NOOP("Output SRT file"), NULL, QT_TR_NOOP("Save SRT file"));
   
   diaElem *elems[]={&selectIdx,&selectSrt,&selectGlyph};
@@ -197,9 +193,9 @@ uint8_t DIA_ocrDvb(void)
   }
 _againX:  
   // Fist build a dialogFactory to get input and output files
-  diaElemFile     selectTs(1,&tsFileName,QT_TR_NOOP("Input TS:"), NULL, QT_TR_NOOP("Select TS file"));
+  diaElemFile     selectTs(0,&tsFileName,QT_TR_NOOP("Input TS:"), NULL, QT_TR_NOOP("Select TS file"));
   diaElemUInteger selectPid(&pid,QT_TR_NOOP("Subtitle PID:"),0,255);
-  diaElemFile     selectGlyph(1,&glyphFileName,QT_TR_NOOP("Use glyphset (optional):"), NULL, QT_TR_NOOP("Select GlyphSet file"));  
+  diaElemFile     selectGlyph(0,&glyphFileName,QT_TR_NOOP("Use GlyphSet (optional):"), NULL, QT_TR_NOOP("Select GlyphSet file"));  
   diaElemFile     selectSrt(1,&srtFileName,QT_TR_NOOP("Output SRT file"), NULL, QT_TR_NOOP("Save SRT file"));
   
   diaElem *elems[]={&selectTs,&selectPid,&selectSrt,&selectGlyph};
