@@ -13,8 +13,8 @@
 //
 
 #include "config.h"
-#include "default.h"
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "ADM_default.h"
+#include "DIA_factory.h"
 
 int DIA_getMPParams( uint32_t *pplevel, uint32_t *ppstrength,uint32_t *swap)
 {
