@@ -1,7 +1,7 @@
 #ifndef ADM_GUI_UI_H
 #define ADM_GUI_UI_H
 
-#include "../ADM_editor/ADM_outputfmt.h"
+#include "ADM_editor/ADM_outputfmt.h"
 
 void UI_updateFrameCount(uint32_t curFrame);
 void UI_setFrameCount(uint32_t curFrame,uint32_t total);
@@ -44,6 +44,7 @@ uint8_t UI_getTimeShift(int *onoff,int *value);
 uint8_t UI_setTimeShift(int onoff,int value);
 
 uint8_t UI_updateRecentMenu( void );
+void UI_updateRecentProjectsMenu(void);
 
 uint8_t UI_arrow_enabled(void);
 uint8_t UI_arrow_disabled(void);
