@@ -18,21 +18,11 @@
  *                                                                         *
  ***************************************************************************/
  
-#include "default.h"
-
-#include "ADM_assert.h"
-#include "fourcc.h"
-#include "avio.hxx"
-#include "avi_vars.h"
-
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-
-#include "ADM_filter/video_filters.h"
-
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "config.h"
+#include "ADM_default.h"
+#include "ADM_videoFilter.h"
 
+#include "DIA_factory.h"
 #include "ADM_vidComputeAverage.h"
 
 static FILTER_PARAM computeAverageParam={5,{"start_frame",
