@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
  
-#include "default.h"
+#include "ADM_default.h"
 
 #include <ctype.h>
 #include <errno.h>
@@ -29,22 +29,18 @@
 
 #include "ADM_assert.h"
 #include "fourcc.h"
-#include "avio.hxx"
 #include "avi_vars.h"
 
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-
+#include "ADM_videoFilter.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
 #include "ADM_encoder/adm_encoder.h"
 
-#include "ADM_filter/video_filters.h"
 
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "DIA_factory.h"
 
 #include "ADM_vidEraser.h"
-#include "DIA_flyDialog.h" // for MenuMapping
+#include "ADM_userInterfaces/ADM_commonUI/DIA_flyDialog.h" // for MenuMapping
 
 using namespace std;
 
