@@ -18,31 +18,27 @@
 #include <math.h>
 #include <algorithm>
 #include <string>
-#include <vector>
-using namespace std;
-
-#include "default.h"
 #include <ctype.h>
 
-#include "ADM_assert.h"
+using namespace std;
+
+#include "ADM_default.h"
+
 #undef memcpy   // avoid compile errors due to macro
 #include "fourcc.h"
-#include "avio.hxx"
-#include "avi_vars.h"
 
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 
 #include "ADM_encoder/ADM_vidEncode.hxx"
 #include "ADM_encoder/adm_encoder.h"
 
 #include "ADM_filter/video_filters.h"
 
-#include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
+#include "DIA_factory.h"
 
 #include "ADM_vidParticle.h"
-#include "DIA_flyDialog.h" // for MenuMapping
+#include "ADM_userInterfaces/ADM_commonUI/DIA_flyDialog.h" // for MenuMapping
 
 FILE * ADMVideoParticle::outfp = 0;
 uint32_t ADMVideoParticle::last_frame_written = 0xffffffff;
@@ -547,7 +543,7 @@ PixelOffset ImageTool::aheadOffset [ImageTool::DIRECTION_COUNT] =
 
 uint8_t ImageTool::autoOutline (uint32_t x, uint32_t y)
 {
-    my_particle.init (debug);
+/*    my_particle.init (debug);
     PixelLocVec & outline = my_particle.outline;
 
     static int needbar = 1;
@@ -1070,7 +1066,7 @@ uint8_t ImageTool::autoOutline (uint32_t x, uint32_t y)
     }
 
 #endif // ? OLD_PARTICLE_WEDGE_SCHEME
-
+*/
     return 1;
 }
 
