@@ -45,42 +45,28 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ADM_assert.h>
 
+#include "ADM_assert.h"
 #include "config.h"
 #include "fourcc.h"
-#include "avio.hxx"
-#include "config.h"
+
 #include "avi_vars.h"
 
 
-
-#include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
-
-
-#include "ADM_toolkit/filesel.h"
-
-#include "ADM_colorspace/colorspace.h"
-
+#include "ADM_videoFilter.h"
+#include "DIA_fileSel.h"
+#include "ADM_colorspace.h"
 #include "ADM_vobsubinfo.h"
-
 #include "ADM_vidVobSub.h"
 
-#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
-extern "C" {
-#include "ADM_lavcodec/avcodec.h"
-}
-#endif
 
-#include "../ADM_lavutil/avutil.h"
-#include "ADM_libswscale/swscale.h"
-#include "ADM_osSupport/ADM_cpuCap.h"
+extern "C" {
+#include "libavcodec/avcodec.h"
+#include "libavutil/avutil.h"
+#include "libswscale/swscale.h"
+}
+
+
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_FILTER
@@ -638,7 +624,7 @@ uint8_t vobSubBitmap::subResize(vobSubBitmap **tgt,uint32_t newx,uint32_t newy,u
   ADM_assert(ctx);
     
   //************************
-  uint8_t *src[3];
+  const uint8_t *src[3];
   uint8_t *dst[3];
   int ssrc[3];
   int ddst[3];
