@@ -16,32 +16,18 @@
 #define HAVE_DETC
 #ifdef HAVE_DETC
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <ADM_assert.h>
-
 #include "config.h"
-
 #include "ADM_lavcodec.h"
-
 #include "fourcc.h"
-#include "avio.hxx"
-#include "config.h"
-#include "avi_vars.h"
-
-
 
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_editor/ADM_edit.hxx"
-#include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_videoFilter.h"
 #include "ADM_video/ADM_mpdetc.h"
 
 #include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_FILTER
 #include "ADM_osSupport/ADM_debug.h"
 
-
 //static void decimate(uint8_t *src,uint8_t *target, uint32_t linessrc, uint32_t width);
 #include "ADM_filter/video_filters.h"
 
@@ -57,7 +43,7 @@ void 		*my_memcpy_pic(uint8_t * dst, uint8_t * src, int bytesPerLine, int height
 						int dstStride, int srcStride);
 unsigned int 	hash_pic(unsigned char *img, int w, int h, int stride);
 static void 	block_diffs_C(struct metrics *m, unsigned char *old, unsigned char *nw, int os, int ns);
-#if defined( ARCH_X86)  || defined(ARCH_X86_64)
+#ifdef ADM_CPU_X86
 void block_diffs_MMX(struct metrics *m, unsigned char *old, unsigned char *ew, int os, int ns);
 #endif
 static void 	diff_planes(struct metrics *m, unsigned char *old, unsigned char *nw, int w, int h, int os, int ns);
