@@ -1,47 +1,27 @@
 #ifndef __AVI_VARS
 #define __AVI_VARS
-#include "default.h"
-#include <assert.h>
+#include "config.h"
 #include "fourcc.h"
 #include "ADM_editor/ADM_edit.hxx"
 //----------------------
 
-
-#define HAVE_ENCODER
-
-
-//----------------------
-//----------------------
-//----------------------
-#if (defined( HAVE_LIBESD) && defined(HAVE_ESD_H)) || \
- defined(OSS_SUPPORT) || defined (USE_ARTS) || \
-  defined(USE_SDL) || defined(CONFIG_DARWIN) || \
-  defined(ADM_WIN32) || defined(ALSA_SUPPORT)
-  
-#define HAVE_AUDIO
-#endif
-//----------------------
-
-
-
 #ifdef __DECLARE__
 #define EXTERN 
 #else
 #define EXTERN extern
 #endif
 
-//
 #define DEBUG
 #define DEBUG_L2
 
 
-
 EXTERN ADM_Composer *video_body
 #ifdef __DECLARE__
 =NULL
 #endif
 ;
 
+
 EXTERN uint32_t  curframe;
 EXTERN uint32_t verbose;
 EXTERN uint32_t originalPriority;
