@@ -20,34 +20,26 @@
  ***************************************************************************/
 #include "config.h"
  
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include "config.h"
 #include "prefs.h"
-
 #include "fourcc.h"
 #include "avi_vars.h"
 #include "ADM_assert.h" 
 
-#include "ADM_toolkit/filesel.h"
+#include "DIA_fileSel.h"
 #include "prototype.h"
 #include "ADM_audiodevice/audio_out.h"
 
-#include "ADM_toolkit/toolkit.hxx"
+#include "DIA_coreToolkit.h"
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiofilter/audioprocess.hxx"
-
-#include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_filter/video_filters.h"
+#include "ADM_videoFilter.h"
+#include "ADM_videoFilter_internal.h"
 #include "gtkgui.h"
-#include "GUI_render.h"
+#include "ADM_userInterfaces/ADM_render/GUI_render.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "ADM_libraries/ADM_utilities/avidemutils.h"
-
+#include "ADM_preview.h"
 //___________________________________
 #define AUDIO_PRELOAD 150
 //___________________________________
@@ -310,8 +302,8 @@ void FillAudio(void)
 void ComputePreload(void)
 //_______________________________________
 {
-    uint32_t latency, one_sec;
-    uint32_t small;
+    uint32_t state,latency, one_sec;
+    uint32_t small_;
     uint32_t channels;
 
     wavbuf = 0;
@@ -347,14 +339,15 @@ void ComputePreload(void)
     one_audio_frame /= 1000; // In elemtary info (float)
     printf("1 audio frame = %lu bytes\n", one_audio_frame);
     // 3 sec buffer..               
-    wavbuf =  (float *)  ADM_alloc((3 *  channels * wavinfo->frequency*wavinfo->channels));
+    wavbuf =  (float *)  ADM_alloc((3 *  2*channels * wavinfo->frequency*wavinfo->channels));
     ADM_assert(wavbuf);
     // Call it twice to be sure it is properly setup
-     latency = AVDM_AudioSetup(playback->getInfo()->frequency,  channels );
+     state = AVDM_AudioSetup(playback->getInfo()->frequency,  channels );
      AVDM_AudioClose();
-     latency = AVDM_AudioSetup(playback->getInfo()->frequency,  channels );
-
-      if (!latency)
+     state = AVDM_AudioSetup(playback->getInfo()->frequency,  channels );
+     latency=AVDM_GetLayencyMs();
+     printf("[Playback] Latency : %d ms\n",latency);
+      if (!state)
       {
           GUI_Error_HIG(QT_TR_NOOP("Trouble initializing audio device"), NULL);
           return;
@@ -364,19 +357,21 @@ void ComputePreload(void)
     // we preload 1/4 a second
      currentaudiostream->beginDecompress();
      one_sec = (wavinfo->frequency *  channels)  >> 2;
-    
+     one_sec+=(latency*wavinfo->frequency *  channels*2)/1000;
      AUD_Status status;
     uint32_t fill=0;
     while(fill<one_sec)
     {
-      if (!(small = playback->fill(one_sec-fill, wavbuf,&status)))
+      if (!(small_ = playback->fill(one_sec-fill, wavbuf,&status)))
       {
         break;
       }
-    fill+=small;
+    fill+=small_;
     }
     dauds += fill/channels;  // In sample
     AVDM_AudioPlay(wavbuf, fill);
+    // Let audio latency sets in...
+    ADM_usleep(latency*1000);
     audio_available = 1;
 }
 
