@@ -100,8 +100,12 @@ extern int check_leaks();
 
 int main(int argc, char *argv[])
 {
-#if defined(__WIN32) && defined(USE_SDL)
-	redirectStdoutToFile();
+	char uiDesc[15];
+	getUIDescription(uiDesc);
+
+#if defined(__WIN32)
+	if (strcmp(uiDesc, "CLI") != 0)
+		redirectStdoutToFile();
 #endif
 
 #if defined(ADM_DEBUG) && defined(FIND_LEAKS)
@@ -123,13 +127,13 @@ int main(int argc, char *argv[])
 
     printf("\n*************************\n");
     printf(" http://www.avidemux.org\n");
-    printf(" Code      : Mean, JSC, Gruntster \n");
-    printf(" GFX       : Nestor Di , nestordi@augcyl.org\n");
+    printf(" Code      : Mean, JSC, Grant Pedersen\n");
+    printf(" GFX       : Nestor Di, nestordi@augcyl.org\n");
     printf(" Design    : Jakub Misak\n");
     printf(" FreeBSD   : Anish Mistry, amistry@am-productions.biz\n");
     printf(" Audio     : Mihail Zenkov\n");
-    printf(" MacOsX    : Kuisathaverat\n");
-    printf(" Win32     : Gruntster\n\n");
+    printf(" Mac OS X  : Kuisathaverat, Harry van der Wolf\n");
+    printf(" Win32     : Grant Pedersen\n\n");
 
 #ifdef __GNUC__
 	printf("Compiler: GCC %s\n", __VERSION__);
@@ -153,11 +157,7 @@ int main(int argc, char *argv[])
 	printf(" (PowerPC)");
 #endif
 
-	printf("\n");
-
-	char uiDesc[15];
-	getUIDescription(uiDesc);
-	printf("User Interface: %s\n", uiDesc);
+	printf("\nUser Interface: %s\n", uiDesc);
 
 #ifdef __WIN32
 	char version[250];
@@ -200,7 +200,6 @@ int main(int argc, char *argv[])
     InitCoreToolkit();
     initFileSelector();
 
-
 	// Load .avidemuxrc
     quotaInit();
 
@@ -319,7 +318,9 @@ void onexit( void )
 #endif
 }
 extern void checkCrashFile(void);
+extern ADMImage *createImageFromFile(const char *filename);
 void dummyXref(void)
 {
     checkCrashFile();
+    createImageFromFile("foobar");
 }
