@@ -8,27 +8,6 @@
 
 // <prefs_gen>
 typedef enum {
-	CODECS_SVCD_ENCTYPE,
-	CODECS_SVCD_BITRATE,
-	CODECS_SVCD_QUANTIZER,
-	CODECS_SVCD_FINALSIZE,
-	CODECS_SVCD_INTERLACED,
-	CODECS_SVCD_BFF,
-	CODECS_SVCD_WIDESCREEN,
-	CODECS_SVCD_MATRIX,
-	CODECS_SVCD_GOPSIZE,
-	CODECS_SVCD_MAXBITRATE,
-	CODECS_DVD_ENCTYPE,
-	CODECS_DVD_BITRATE,
-	CODECS_DVD_QUANTIZER,
-	CODECS_DVD_FINALSIZE,
-	CODECS_DVD_INTERLACED,
-	CODECS_DVD_BFF,
-	CODECS_DVD_WIDESCREEN,
-	CODECS_DVD_MATRIX,
-	CODECS_DVD_GOPSIZE,
-	CODECS_DVD_MAXBITRATE,
-	CODECS_PREFERREDCODEC,
 	FILTERS_SUBTITLE_FONTNAME,
 	FILTERS_SUBTITLE_CHARSET,
 	FILTERS_SUBTITLE_FONTSIZE,
@@ -83,7 +62,8 @@ typedef enum {
 	FEATURE_GLOBAL_GLYPH_NAME,
 	PRIORITY_ENCODING,
 	PRIORITY_INDEXING,
-	PRIORITY_PLAYBACK
+	PRIORITY_PLAYBACK,
+	PLUGIN_ORDER
 } options;
 // </prefs_gen>
 
