@@ -6,8 +6,6 @@ void    GUI_RGBDisplay(uint8_t *dis,uint32_t w,uint32_t h,void *widg);
 // Render
 
 uint8_t	 GUI_Refresh( void );
-
-uint8_t GUI_ConvertRGB(uint8_t *in,uint8_t *out,uint32_t w,uint32_t h);
 uint8_t	GUI_XvRedraw(void);
 
 // GUI
@@ -16,7 +14,7 @@ void GUI_GoToKFrame(uint32_t frame); // same as below execpt
 int GUI_GoToFrame(uint32_t frame);
 // not in callback.h to avoid importing COMPRESSION MODE in interface.cpp
 
- void updateVideoFilters(void);
+
  //
  //
  //
