@@ -211,7 +211,6 @@ static av_cold int ape_decode_close(AVCodecContext * avctx)
     for (i = 0; i < APE_FILTER_LEVELS; i++)
         av_freep(&s->filterbuf[i]);
 
-    av_freep(&s->data);
     return 0;
 }
 
@@ -518,9 +517,9 @@ static inline int APESIGN(int32_t x) {
     return (x < 0) - (x > 0);
 }
 
-static av_always_inline int predictor_update_filter(APEPredictor *p, const int decoded, const int filter, const int delayA, const int delayB, const int adaptA, const int adaptB)
+static int predictor_update_filter(APEPredictor *p, const int decoded, const int filter, const int delayA, const int delayB, const int adaptA, const int adaptB)
 {
-    int32_t predictionA, predictionB, sign;
+    int32_t predictionA, predictionB;
 
     p->buf[delayA]     = p->lastA[filter];
     p->buf[adaptA]     = APESIGN(p->buf[delayA]);
@@ -548,32 +547,48 @@ static av_always_inline int predictor_update_filter(APEPredictor *p, const int d
     p->lastA[filter] = decoded + ((predictionA + (predictionB >> 1)) >> 10);
     p->filterA[filter] = p->lastA[filter] + ((p->filterA[filter] * 31) >> 5);
 
-    sign = APESIGN(decoded);
-    p->coeffsA[filter][0] += p->buf[adaptA    ] * sign;
-    p->coeffsA[filter][1] += p->buf[adaptA - 1] * sign;
-    p->coeffsA[filter][2] += p->buf[adaptA - 2] * sign;
-    p->coeffsA[filter][3] += p->buf[adaptA - 3] * sign;
-    p->coeffsB[filter][0] += p->buf[adaptB    ] * sign;
-    p->coeffsB[filter][1] += p->buf[adaptB - 1] * sign;
-    p->coeffsB[filter][2] += p->buf[adaptB - 2] * sign;
-    p->coeffsB[filter][3] += p->buf[adaptB - 3] * sign;
-    p->coeffsB[filter][4] += p->buf[adaptB - 4] * sign;
+    if (!decoded) // no need updating filter coefficients
+        return p->filterA[filter];
 
+    if (decoded > 0) {
+        p->coeffsA[filter][0] -= p->buf[adaptA    ];
+        p->coeffsA[filter][1] -= p->buf[adaptA - 1];
+        p->coeffsA[filter][2] -= p->buf[adaptA - 2];
+        p->coeffsA[filter][3] -= p->buf[adaptA - 3];
+
+        p->coeffsB[filter][0] -= p->buf[adaptB    ];
+        p->coeffsB[filter][1] -= p->buf[adaptB - 1];
+        p->coeffsB[filter][2] -= p->buf[adaptB - 2];
+        p->coeffsB[filter][3] -= p->buf[adaptB - 3];
+        p->coeffsB[filter][4] -= p->buf[adaptB - 4];
+    } else {
+        p->coeffsA[filter][0] += p->buf[adaptA    ];
+        p->coeffsA[filter][1] += p->buf[adaptA - 1];
+        p->coeffsA[filter][2] += p->buf[adaptA - 2];
+        p->coeffsA[filter][3] += p->buf[adaptA - 3];
+
+        p->coeffsB[filter][0] += p->buf[adaptB    ];
+        p->coeffsB[filter][1] += p->buf[adaptB - 1];
+        p->coeffsB[filter][2] += p->buf[adaptB - 2];
+        p->coeffsB[filter][3] += p->buf[adaptB - 3];
+        p->coeffsB[filter][4] += p->buf[adaptB - 4];
+    }
     return p->filterA[filter];
 }
 
 static void predictor_decode_stereo(APEContext * ctx, int count)
 {
+    int32_t predictionA, predictionB;
     APEPredictor *p = &ctx->predictor;
     int32_t *decoded0 = ctx->decoded0;
     int32_t *decoded1 = ctx->decoded1;
 
     while (count--) {
         /* Predictor Y */
-        *decoded0 = predictor_update_filter(p, *decoded0, 0, YDELAYA, YDELAYB, YADAPTCOEFFSA, YADAPTCOEFFSB);
-        decoded0++;
-        *decoded1 = predictor_update_filter(p, *decoded1, 1, XDELAYA, XDELAYB, XADAPTCOEFFSA, XADAPTCOEFFSB);
-        decoded1++;
+        predictionA = predictor_update_filter(p, *decoded0, 0, YDELAYA, YDELAYB, YADAPTCOEFFSA, YADAPTCOEFFSB);
+        predictionB = predictor_update_filter(p, *decoded1, 1, XDELAYA, XDELAYB, XADAPTCOEFFSA, XADAPTCOEFFSB);
+        *(decoded0++) = predictionA;
+        *(decoded1++) = predictionB;
 
         /* Combined */
         p->buf++;
@@ -590,7 +605,7 @@ static void predictor_decode_mono(APEContext * ctx, int count)
 {
     APEPredictor *p = &ctx->predictor;
     int32_t *decoded0 = ctx->decoded0;
-    int32_t predictionA, currentA, A, sign;
+    int32_t predictionA, currentA, A;
 
     currentA = p->lastA[0];
 
@@ -610,11 +625,17 @@ static void predictor_decode_mono(APEContext * ctx, int count)
         p->buf[YADAPTCOEFFSA]     = APESIGN(p->buf[YDELAYA    ]);
         p->buf[YADAPTCOEFFSA - 1] = APESIGN(p->buf[YDELAYA - 1]);
 
-        sign = APESIGN(A);
-        p->coeffsA[0][0] += p->buf[YADAPTCOEFFSA    ] * sign;
-        p->coeffsA[0][1] += p->buf[YADAPTCOEFFSA - 1] * sign;
-        p->coeffsA[0][2] += p->buf[YADAPTCOEFFSA - 2] * sign;
-        p->coeffsA[0][3] += p->buf[YADAPTCOEFFSA - 3] * sign;
+        if (A > 0) {
+            p->coeffsA[0][0] -= p->buf[YADAPTCOEFFSA    ];
+            p->coeffsA[0][1] -= p->buf[YADAPTCOEFFSA - 1];
+            p->coeffsA[0][2] -= p->buf[YADAPTCOEFFSA - 2];
+            p->coeffsA[0][3] -= p->buf[YADAPTCOEFFSA - 3];
+        } else if (A < 0) {
+            p->coeffsA[0][0] += p->buf[YADAPTCOEFFSA    ];
+            p->coeffsA[0][1] += p->buf[YADAPTCOEFFSA - 1];
+            p->coeffsA[0][2] += p->buf[YADAPTCOEFFSA - 2];
+            p->coeffsA[0][3] += p->buf[YADAPTCOEFFSA - 3];
+        }
 
         p->buf++;
 
@@ -649,16 +670,22 @@ static void init_filter(APEContext * ctx, APEFilter *f, int16_t * buf, int order
     do_init_filter(&f[1], buf + order * 3 + HISTORY_SIZE, order);
 }
 
-static void do_apply_filter(APEContext * ctx, int version, APEFilter *f, int32_t *data, int count, int order, int fracbits)
+static inline void do_apply_filter(APEContext * ctx, int version, APEFilter *f, int32_t *data, int count, int order, int fracbits)
 {
     int res;
     int absres;
 
     while (count--) {
         /* round fixedpoint scalar product */
-        res = ctx->dsp.scalarproduct_and_madd_int16(f->coeffs, f->delay - order, f->adaptcoeffs - order, order, APESIGN(*data));
-        res = (res + (1 << (fracbits - 1))) >> fracbits;
+        res = (ctx->dsp.scalarproduct_int16(f->delay - order, f->coeffs, order, 0) + (1 << (fracbits - 1))) >> fracbits;
+
+        if (*data < 0)
+            ctx->dsp.add_int16(f->coeffs, f->adaptcoeffs - order, order);
+        else if (*data > 0)
+            ctx->dsp.sub_int16(f->coeffs, f->adaptcoeffs - order, order);
+
         res += *data;
+
         *data++ = res;
 
         /* Update the output history */
@@ -673,9 +700,14 @@ static void do_apply_filter(APEContext * ctx, int version, APEFilter *f, int32_t
             /* Version 3.98 and later files */
 
             /* Update the adaption coefficients */
-            absres = FFABS(res);
-            if (absres)
-                *f->adaptcoeffs = ((res & (1<<31)) - (1<<30)) >> (25 + (absres <= f->avg*3) + (absres <= f->avg*4/3));
+            absres = (res < 0 ? -res : res);
+
+            if (absres > (f->avg * 3))
+                *f->adaptcoeffs = ((res >> 25) & 64) - 32;
+            else if (absres > (f->avg * 4) / 3)
+                *f->adaptcoeffs = ((res >> 26) & 32) - 16;
+            else if (absres > 0)
+                *f->adaptcoeffs = ((res >> 27) & 16) - 8;
             else
                 *f->adaptcoeffs = 0;
 
@@ -855,7 +887,6 @@ static int ape_decode_frame(AVCodecContext * avctx,
         ape_unpack_mono(s, blockstodecode);
     else
         ape_unpack_stereo(s, blockstodecode);
-    emms_c();
 
     if(s->error || s->ptr > s->data_end){
         s->samples=0;
@@ -879,7 +910,7 @@ static int ape_decode_frame(AVCodecContext * avctx,
 
 AVCodec ape_decoder = {
     "ape",
-    AVMEDIA_TYPE_AUDIO,
+    CODEC_TYPE_AUDIO,
     CODEC_ID_APE,
     sizeof(APEContext),
     ape_decode_init,
