@@ -38,7 +38,6 @@
 #include "avcodec.h"
 #include "get_bits.h"
 #include "dsputil.h"
-#include "fft.h"
 
 #include "imcdata.h"
 
@@ -85,8 +84,8 @@ typedef struct {
 
     DSPContext dsp;
     FFTContext fft;
-    DECLARE_ALIGNED(16, FFTComplex, samples)[COEFFS/2];
-    DECLARE_ALIGNED(16, float, out_samples)[COEFFS];
+    DECLARE_ALIGNED_16(FFTComplex, samples[COEFFS/2]);
+    DECLARE_ALIGNED_16(float, out_samples[COEFFS]);
 } IMCContext;
 
 static VLC huffman_vlc[4][4];
@@ -823,7 +822,7 @@ static av_cold int imc_decode_close(AVCodecContext * avctx)
 
 AVCodec imc_decoder = {
     .name = "imc",
-    .type = AVMEDIA_TYPE_AUDIO,
+    .type = CODEC_TYPE_AUDIO,
     .id = CODEC_ID_IMC,
     .priv_data_size = sizeof(IMCContext),
     .init = imc_decode_init,
