@@ -598,8 +598,8 @@ static void lspf2lpc(const float *lspf, float *lpc)
  * @param lpc float vector for the resulting LPC
  * @param subframe_num frame number in decoded stream
  */
-static void interpolate_lpc(QCELPContext *q, const float *curr_lspf,
-                            float *lpc, const int subframe_num)
+void interpolate_lpc(QCELPContext *q, const float *curr_lspf, float *lpc,
+                     const int subframe_num)
 {
     float interpolated_lspf[10];
     float weight;
@@ -813,7 +813,7 @@ erasure:
 AVCodec qcelp_decoder =
 {
     .name   = "qcelp",
-    .type   = AVMEDIA_TYPE_AUDIO,
+    .type   = CODEC_TYPE_AUDIO,
     .id     = CODEC_ID_QCELP,
     .init   = qcelp_decode_init,
     .decode = qcelp_decode_frame,
