@@ -32,7 +32,7 @@
 #include "tiff.h"
 #include "faxcompr.h"
 #include "libavutil/common.h"
-#include "libavutil/intreadwrite.h"
+
 
 typedef struct TiffContext {
     AVCodecContext *avctx;
@@ -592,7 +592,7 @@ static av_cold int tiff_end(AVCodecContext *avctx)
 
 AVCodec tiff_decoder = {
     "tiff",
-    AVMEDIA_TYPE_VIDEO,
+    CODEC_TYPE_VIDEO,
     CODEC_ID_TIFF,
     sizeof(TiffContext),
     tiff_init,
