@@ -30,7 +30,6 @@
 #include "avcodec.h"
 #include "get_bits.h"
 #include "dsputil.h"
-#include "fft.h"
 
 #include "vorbis.h"
 #include "xiph.h"
@@ -951,7 +950,7 @@ static av_cold int vorbis_decode_init(AVCodecContext *avccontext)
     }
 
     if (!headers_len) {
-        av_log(avccontext, AV_LOG_ERROR, "Extradata missing.\n");
+        av_log(avccontext, AV_LOG_ERROR, "Extradata corrupt.\n");
         return -1;
     }
 
@@ -985,7 +984,7 @@ static av_cold int vorbis_decode_init(AVCodecContext *avccontext)
         return -1;
     }
 
-    if (vc->audio_channels > 8)
+    if (vc->audio_channels > 6)
         avccontext->channel_layout = 0;
     else
         avccontext->channel_layout = ff_vorbis_channel_layouts[vc->audio_channels - 1];
@@ -1617,7 +1616,7 @@ static int vorbis_decode_frame(AVCodecContext *avccontext,
 
     AV_DEBUG("parsed %d bytes %d bits, returned %d samples (*ch*bits) \n", get_bits_count(gb)/8, get_bits_count(gb)%8, len);
 
-    if (vc->audio_channels > 8) {
+    if (vc->audio_channels > 6) {
         for (i = 0; i < vc->audio_channels; i++)
             channel_ptrs[i] = vc->channel_floors + i * len;
     } else {
@@ -1645,7 +1644,7 @@ static av_cold int vorbis_decode_close(AVCodecContext *avccontext)
 
 AVCodec vorbis_decoder = {
     "vorbis",
-    AVMEDIA_TYPE_AUDIO,
+    CODEC_TYPE_AUDIO,
     CODEC_ID_VORBIS,
     sizeof(vorbis_context),
     vorbis_decode_init,
