@@ -21,7 +21,7 @@
  */
 
 /**
- * @file  libavcodec/wmaprodec.c
+ * @file
  * @brief wmapro decoder implementation
  * Wmapro is an MDCT based codec comparable to wma standard or AAC.
  * The decoding therefore consists of the following steps:
@@ -296,7 +296,7 @@ static av_cold int decode_init(AVCodecContext *avctx)
     s->log2_frame_size = av_log2(avctx->block_align) + 4;
 
     /** frame info */
-    s->skip_frame  = 1; /** skip first frame */
+    s->skip_frame  = 1; /* skip first frame */
     s->packet_loss = 1;
     s->len_prefix  = (s->decode_flags & 0x40);
 
@@ -508,11 +508,11 @@ static int decode_subframe_length(WMAProDecodeCtx *s, int offset)
  */
 static int decode_tilehdr(WMAProDecodeCtx *s)
 {
-    uint16_t num_samples[WMAPRO_MAX_CHANNELS];        /** sum of samples for all currently known subframes of a channel */
-    uint8_t  contains_subframe[WMAPRO_MAX_CHANNELS];  /** flag indicating if a channel contains the current subframe */
-    int channels_for_cur_subframe = s->num_channels;  /** number of channels that contain the current subframe */
-    int fixed_channel_layout = 0;                     /** flag indicating that all channels use the same subframe offsets and sizes */
-    int min_channel_len = 0;                          /** smallest sum of samples (channels with this length will be processed first) */
+    uint16_t num_samples[WMAPRO_MAX_CHANNELS];        /**< sum of samples for all currently known subframes of a channel */
+    uint8_t  contains_subframe[WMAPRO_MAX_CHANNELS];  /**< flag indicating if a channel contains the current subframe */
+    int channels_for_cur_subframe = s->num_channels;  /**< number of channels that contain the current subframe */
+    int fixed_channel_layout = 0;                     /**< flag indicating that all channels use the same subframe offsets and sizes */
+    int min_channel_len = 0;                          /**< smallest sum of samples (channels with this length will be processed first) */
     int c;
 
     /* Should never consume more than 3073 bits (256 iterations for the
@@ -1351,8 +1351,9 @@ static int decode_frame(WMAProDecodeCtx *s)
         float* iptr = s->channel[i].out;
         float* iend = iptr + s->samples_per_frame;
 
+        // FIXME should create/use a DSP function here
         while (iptr < iend) {
-            *ptr = av_clipf(*iptr++, -1.0, 32767.0 / 32768.0);
+            *ptr = *iptr++;
             ptr += incr;
         }
 
