@@ -20,7 +20,7 @@
  */
 
 /**
- * @file libavcodec/zmbv.c
+ * @file
  * Zip Motion Blocks Video decoder
  */
 
@@ -397,7 +397,6 @@ static int decode_frame(AVCodecContext *avctx, void *data, int *data_size, AVPac
     const uint8_t *buf = avpkt->data;
     int buf_size = avpkt->size;
     ZmbvContext * const c = avctx->priv_data;
-    uint8_t *outptr;
     int zret = Z_OK; // Zlib return code
     int len = buf_size;
     int hi_ver, lo_ver;
@@ -412,8 +411,6 @@ static int decode_frame(AVCodecContext *avctx, void *data, int *data_size, AVPac
         return -1;
     }
 
-    outptr = c->pic.data[0]; // Output image pointer
-
     /* parse header */
     c->flags = buf[0];
     buf++; len--;
