@@ -20,7 +20,7 @@
  */
 #include "avformat.h"
 #include "flv.h"
-#include "riff.h"
+#include "internal.h"
 #include "avc.h"
 
 #undef NDEBUG
@@ -54,6 +54,7 @@ typedef struct FLVContext {
     int64_t filesize_offset;
     int64_t duration;
     int delay; ///< first dts delay for AVC
+    int64_t last_video_ts;
 } FLVContext;
 
 static int get_audio_flags(AVCodecContext *enc){
@@ -144,6 +145,18 @@ static void put_amf_string(ByteIOContext *pb, const char *str)
     put_buffer(pb, str, len);
 }
 
+static void put_avc_eos_tag(ByteIOContext *pb, unsigned ts) {
+    put_byte(pb, FLV_TAG_TYPE_VIDEO);
+    put_be24(pb, 5);  /* Tag Data Size */
+    put_be24(pb, ts);  /* lower 24 bits of timestamp in ms*/
+    put_byte(pb, (ts >> 24) & 0x7F);  /* MSB of ts in ms*/
+    put_be24(pb, 0);  /* StreamId = 0 */
+    put_byte(pb, 23);  /* ub[4] FrameType = 1, ub[4] CodecId = 7 */
+    put_byte(pb, 2);  /* AVC end of sequence */
+    put_be24(pb, 0);  /* Always 0 for AVC EOS. */
+    put_be32(pb, 16);  /* Size of FLV tag */
+}
+
 static void put_amf_double(ByteIOContext *pb, double d)
 {
     put_byte(pb, AMF_DATA_TYPE_NUMBER);
@@ -202,6 +215,8 @@ static int flv_write_header(AVFormatContext *s)
         }
     }
 
+    flv->last_video_ts = -1;
+
     /* write meta_tag */
     put_byte(pb, 18);         // tag type META
     metadata_size_pos= url_ftell(pb);
@@ -309,6 +324,16 @@ static int flv_write_trailer(AVFormatContext *s)
 
     ByteIOContext *pb = s->pb;
     FLVContext *flv = s->priv_data;
+    int i;
+
+    /* Add EOS tag */
+    for (i = 0; i < s->nb_streams; i++) {
+        AVCodecContext *enc = s->streams[i]->codec;
+        if (enc->codec_type == CODEC_TYPE_VIDEO &&
+                enc->codec_id == CODEC_ID_H264) {
+            put_avc_eos_tag(pb, flv->last_video_ts);
+        }
+    }
 
     file_size = url_ftell(pb);
 
@@ -372,6 +397,10 @@ static int flv_write_packet(AVFormatContext *s, AVPacket *pkt)
     }
 
     ts = pkt->dts + flv->delay; // add delay to force positive dts
+    if (enc->codec_type == CODEC_TYPE_VIDEO) {
+        if (flv->last_video_ts < ts)
+            flv->last_video_ts = ts;
+    }
     put_be24(pb,size + flags_size);
     put_be24(pb,ts);
     put_byte(pb,(ts >> 24) & 0x7F); // timestamps are 32bits _signed_
