@@ -2,7 +2,7 @@
 #define AUDM_AFTEN_PARAM_H
 
 
-typedef struct AFTEN_encoderParam
+struct AFTEN_encoderParam
 {
   uint32_t        bitrate;
   ADM_mode        mode;
