@@ -193,29 +193,10 @@ int x264Encoder::open(vidEncVideoProperties *properties)
 	_buffer = new uint8_t[_bufferSize];
 
 	memcpy(&_properties, properties, sizeof(vidEncVideoProperties));
-	updateEncodeParameters(&_properties);
-
-	_param.i_width = _properties.width;
-	_param.i_height = _properties.height;
-	_param.i_fps_num = _properties.fpsNum;
-	_param.i_fps_den = _properties.fpsDen;
-
-	if (_options.getSarAsInput())
-	{
-		_param.vui.i_sar_width = _properties.parWidth;
-		_param.vui.i_sar_height = _properties.parHeight;
-	}
-
-	if (properties->flags & ADM_VIDENC_FLAG_GLOBAL_HEADER)
-		_param.b_repeat_headers = 0;
-	else
-		_param.b_repeat_headers = 1;
 
 	properties->supportedCspsCount = 1;
 	properties->supportedCsps = supportedCsps;
 
-	printParam(&_param);
-
 	return ADM_VIDENC_ERR_SUCCESS;
 }
 
@@ -245,6 +226,7 @@ int x264Encoder::beginPass(vidEncPassParameters *passParameters)
 	char *logFileName = NULL;
 
 	printf("[x264] begin pass %d/%d\n", _currentPass, _passCount);
+	updateEncodeParameters(&_properties);
 
 	if (_passCount > 1)
 	{
@@ -278,6 +260,12 @@ int x264Encoder::beginPass(vidEncPassParameters *passParameters)
 		_param.rc.b_stat_read = 0;
 	}
 
+#if X264_BUILD > 85
+	if (_passCount > 1 && _currentPass == 1 && _options.getFastFirstPass())
+		x264_param_apply_fastfirstpass(&_param);
+#endif
+
+	printParam(&_param);
 	_handle = x264_encoder_open(&_param);
 
 	if (logFileName)
@@ -327,7 +315,6 @@ int x264Encoder::encodeFrame(vidEncEncodeParameters *encodeParams)
 		_picture.img.i_plane = 3;
 	}
 
-#if X264_BUILD > 75
 	if (x264_encoder_encode(_handle, &nal, &nalCount, encodeParams->frameData[0] ? &_picture : NULL, &picture_out) < 0)
 	{
 		printf("[x264] Error encoding\n");
@@ -343,80 +330,27 @@ int x264Encoder::encodeFrame(vidEncEncodeParameters *encodeParams)
 	}
 
 	encodeParams->encodedDataSize = size;
-#else
-	if (x264_encoder_encode(_handle, &nal, &nalCount, encodeParams->frameData[0] ? &_picture : NULL, &picture_out) < 0)
-	{
-		printf("[x264] Error encoding\n");
-		return ADM_VIDENC_ERR_FAILED;
-	}
-
-	int size = 0;
-	int currentNal, sizemax;
-
-	for (int i = 0; i < nalCount; i++)
-	{
-		sizemax = 0xfffffff;
-
-		if (!_param.b_repeat_headers)
-			size += 4;
-
-		currentNal = x264_nal_encode(_buffer + size, &sizemax, _param.b_repeat_headers, &nal[i]);
-
-		if (!_param.b_repeat_headers)
-		{
-			// Need to put size (assuming nal_size=4)
-			_buffer[size + 0 - 4] = (currentNal >> 24) & 0xff;
-			_buffer[size + 1 - 4] = (currentNal >> 16) & 0xff;
-			_buffer[size + 2 - 4] = (currentNal >> 8) & 0xff;
-			_buffer[size + 3 - 4] = (currentNal >> 0) & 0xff;
-		}
-
-		size += currentNal;
-	}
-
-	encodeParams->encodedDataSize = size;
-#endif
 
 	_currentFrame++;
 	encodeParams->ptsFrame = picture_out.i_pts;	// In fact it is the picture number in out case
 
-	switch (picture_out.i_type)
+	if (picture_out.b_keyframe)
+		encodeParams->frameType = ADM_VIDENC_FRAMETYPE_IDR;
+	else
 	{
-		case X264_TYPE_IDR:
-			encodeParams->frameType = ADM_VIDENC_FRAMETYPE_IDR;
-#if X264_BUILD < 76
-			if(!_param.b_repeat_headers && _seiUserData && !picture_out.i_pts)
-			{
-				// Put our SEI front...
-				// first a temp location...
-				uint8_t tmpBuffer[size];
-				memcpy(tmpBuffer, _buffer, size);
-
-				// Put back out SEI and add Size
-				_buffer[0] = (_seiUserDataLen >> 24) & 0xff;
-				_buffer[1] = (_seiUserDataLen >> 16) & 0xff;
-				_buffer[2] = (_seiUserDataLen >> 8) & 0xff;
-				_buffer[3] = (_seiUserDataLen >> 0) & 0xff;
-
-				memcpy(_buffer + 4, _seiUserData, _seiUserDataLen);
-				memcpy(_buffer + 4 + _seiUserDataLen, tmpBuffer, size);
-
-				size += 4 + _seiUserDataLen;
-				encodeParams->encodedDataSize = size; // update total size
-			}
-#endif
-
-			break;
-		case X264_TYPE_I:
-		case X264_TYPE_P:
-			encodeParams->frameType = ADM_VIDENC_FRAMETYPE_P;
-			break;
-		case X264_TYPE_B:
-		case X264_TYPE_BREF:
-			encodeParams->frameType = ADM_VIDENC_FRAMETYPE_B;
-			break;
-		default:
-			encodeParams->frameType = ADM_VIDENC_FRAMETYPE_NULL;
+		switch (picture_out.i_type)
+		{
+			case X264_TYPE_I:
+			case X264_TYPE_P:
+				encodeParams->frameType = ADM_VIDENC_FRAMETYPE_P;
+				break;
+			case X264_TYPE_B:
+			case X264_TYPE_BREF:
+				encodeParams->frameType = ADM_VIDENC_FRAMETYPE_B;
+				break;
+			default:
+				encodeParams->frameType = ADM_VIDENC_FRAMETYPE_NULL;
+		}
 	}
 
 	encodeParams->quantiser = picture_out.i_qpplus1 - 1;
@@ -425,7 +359,6 @@ int x264Encoder::encodeFrame(vidEncEncodeParameters *encodeParams)
 	return ADM_VIDENC_ERR_SUCCESS;
 }
 
-#if X264_BUILD > 75
 int x264Encoder::encodeNals(uint8_t *buf, int size, x264_nal_t *nals, int nalCount, bool skipSei)
 {
     uint8_t *p = buf;
@@ -454,7 +387,6 @@ int x264Encoder::encodeNals(uint8_t *buf, int size, x264_nal_t *nals, int nalCou
 
     return p - buf;
 }
-#endif
 
 bool x264Encoder::createHeader(void)
 {
@@ -467,98 +399,9 @@ bool x264Encoder::createHeader(void)
 	if (_extraData)
 		delete _extraData;
 
-#if X264_BUILD > 75
 	_extraDataSize = x264_encoder_headers(_handle, &nal, &nalCount);
 	_extraData = new uint8_t[_extraDataSize];
 	_extraDataSize = encodeNals(_extraData, _extraDataSize, nal, nalCount, true);
-#else
-	uint32_t offset = 0;
-	uint8_t buffer[X264_MAX_HEADER_SIZE];
-	uint8_t picParam[X264_MAX_HEADER_SIZE];
-	uint8_t seqParam[X264_MAX_HEADER_SIZE];
-	uint8_t sei[X264_MAX_HEADER_SIZE];
-	int picParamLen = 0, seqParamLen = 0, seiParamLen = 0, len;
-	int sz;
-
-	_extraData = new uint8_t[X264_MAX_HEADER_SIZE];
-	_extraDataSize = 0;
-
-	x264_encoder_headers(_handle, &nal, &nalCount);
-
-	printf("[x264] Nal count: %d\n", nalCount);
-
-	// Now encode them
-	for (int i = 0; i < nalCount; i++)
-	{
-		switch (nal[i].i_type)
-		{
-		case H264_NAL_TYPE_SEQ_PARAM:
-			sz = x264_nal_encode(seqParam, &seqParamLen, 0, &nal[i]);
-			break;
-		case H264_NAL_TYPE_PIC_PARAM:
-			sz = x264_nal_encode(picParam, &picParamLen, 0, &nal[i]);
-			break;
-		case H264_NAL_TYPE_SEI:
-			sz = x264_nal_encode(sei, &seiParamLen, 0, &nal[i]);
-			break;
-		default:
-			printf("[x264] Unknown type %d in nal %d\n", nal[i].i_type, i);
-			sz = x264_nal_encode(buffer, &len, 0, &nal[i]);
-		}
-
-		if (sz <= 0)
-		{
-			printf("[x264] Cannot encode nal header %d\n", i);
-
-			return false;
-		}
-	}
-
-	// Now that we got all the nals encoded, time to build the avcC atom
-	// Check we have everything we want
-	if (!picParamLen || !seqParamLen)
-	{
-		printf("[x264] Seqparam or PicParam not found\n");
-		return false;
-	}
-
-	// Fill header
-	_extraData[0] = 1;		// Version
-	_extraData[1] = seqParam[1];	//0x42; // AVCProfileIndication
-	_extraData[2] = seqParam[2];	//0x00; // profile_compatibility
-	_extraData[3] = seqParam[3];	//0x0D; // AVCLevelIndication
-	_extraData[4] = 0xFC + 3;	// lengthSizeMinusOne 
-	_extraData[5] = 0xE0 + 1;	// nonReferenceDegredationPriorityLow
-
-	offset = 6;
-	_extraData[offset] = seqParamLen >> 8;
-	_extraData[offset + 1] = seqParamLen & 0xff;
-
-	offset += 2;
-	memcpy(_extraData + offset, seqParam, seqParamLen);
-
-	offset += seqParamLen;
-	_extraData[offset] = 1;	// numOfPictureParameterSets
-
-	offset++;
-	_extraData[offset] = picParamLen >> 8;
-	_extraData[offset + 1] = picParamLen & 0xff;
-
-	offset += 2;
-	memcpy(_extraData + offset, picParam, picParamLen);
-
-	offset += picParamLen;
-
-	// Where x264 stores all its header, save it for later use
-	if (seiParamLen)
-	{
-		_seiUserDataLen = seiParamLen;
-		_seiUserData = new uint8_t[_seiUserDataLen];
-		memcpy(_seiUserData, sei, _seiUserDataLen);
-	}
-
-	_extraDataSize = offset;
-#endif
 
 	printf("[x264] generated %d extra bytes for header\n", _extraDataSize);
 
@@ -624,10 +467,16 @@ void x264Encoder::printParam(x264_param_t *x264Param)
 
 	printf("\n[x264] i_width = %d, i_height = %d\n", x264Param->i_width, x264Param->i_height);
 	printf("[x264] i_csp = %d\n", x264Param->i_csp);	
+#if X264_BUILD > 88
+	printf("[x264] i_nal_hrd = %d\n", x264Param->i_nal_hrd);
+#endif
 	printf("[x264] i_fps_num = %d, i_fps_den = %d\n", x264Param->i_fps_num, x264Param->i_fps_den);
 	printf("[x264] rc.i_rc_method = %d\n", x264Param->rc.i_rc_method);
 	printf("[x264] rc.i_bitrate = %d\n", x264Param->rc.i_bitrate);
 	printf("[x264] rc.f_rf_constant = %f\n", x264Param->rc.f_rf_constant);
+#if X264_BUILD > 89
+	printf("[x264] rc.f_rf_constant_max = %f\n", x264Param->rc.f_rf_constant_max);
+#endif
 	printf("[x264] rc.i_qp_constant = %d\n", x264Param->rc.i_qp_constant);	
 	printf("[x264] analyse.i_subpel_refine = %d\n", x264Param->analyse.i_subpel_refine);
 	printf("[x264] analyse.i_me_method = %d\n", x264Param->analyse.i_me_method);
@@ -639,22 +488,28 @@ void x264Encoder::printParam(x264_param_t *x264Param)
 	printf("[x264] analyse.b_transform_8x8 = %d\n", x264Param->analyse.b_transform_8x8);
 	printf("[x264] analyse.inter = %d\n", x264Param->analyse.inter);
 	printf("[x264] b_cabac = %d\n", x264Param->b_cabac);
+#if X264_BUILD > 101
+	printf("[x264] i_open_gop = %d\n", x264Param->i_open_gop);
+#endif
 	printf("[x264] b_interlaced = %d\n", x264Param->b_interlaced);
+#if X264_BUILD > 88
+	printf("[x264] b_tff = %d\n", x264Param->b_tff);
+#endif
+#if X264_BUILD > 95
+	printf("[x264] b_fake_interlaced = %d\n", x264Param->b_fake_interlaced);
+#endif
 	printf("[x264] b_deblocking_filter = %d\n", x264Param->b_deblocking_filter);
 	printf("[x264] i_deblocking_filter_alphac0 = %d\n", x264Param->i_deblocking_filter_alphac0);
 	printf("[x264] i_deblocking_filter_beta = %d\n", x264Param->i_deblocking_filter_beta);
 	printf("[x264] i_bframe = %d\n", x264Param->i_bframe);
 	printf("[x264] i_bframe_bias = %d\n", x264Param->i_bframe_bias);
 	printf("[x264] i_frame_reference = %d\n", x264Param->i_frame_reference);
-#if X264_BUILD >= 78
 	printf("[x264] i_bframe_pyramid = %d\n", x264Param->i_bframe_pyramid);
-#else
-	printf("[x264] b_bframe_pyramid = %d\n", x264Param->b_bframe_pyramid);
-#endif
 	printf("[x264] i_bframe_adaptive = %d\n", x264Param->i_bframe_adaptive);
 	printf("[x264] i_keyint_max = %d\n", x264Param->i_keyint_max);
 	printf("[x264] i_keyint_min = %d\n", x264Param->i_keyint_min);
 	printf("[x264] i_scenecut_threshold = %d\n", x264Param->i_scenecut_threshold);
+	printf("[x264] b_intra_refresh = %d\n", x264Param->b_intra_refresh);
 	printf("[x264] analyse.b_mixed_references = %d\n", x264Param->analyse.b_mixed_references);
 	printf("[x264] analyse.b_chroma_me = %d\n", x264Param->analyse.b_chroma_me);
 	printf("[x264] analyse.i_trellis = %d\n", x264Param->analyse.i_trellis);
@@ -752,6 +607,25 @@ void x264Encoder::updateEncodeParameters(vidEncVideoProperties *properties)
 			_param.rc.i_bitrate = _encodeOptions.encodeModeParameter;
 			break;
 	}
+
+	if (properties)
+	{
+		_param.i_width = properties->width;
+		_param.i_height = properties->height;
+		_param.i_fps_num = properties->fpsNum;
+		_param.i_fps_den = properties->fpsDen;
+
+		if (_options.getSarAsInput())
+		{
+			_param.vui.i_sar_width = properties->parWidth;
+			_param.vui.i_sar_height = properties->parHeight;
+		}
+
+		if (properties->flags & ADM_VIDENC_FLAG_GLOBAL_HEADER)
+			_param.b_repeat_headers = 0;
+		else
+			_param.b_repeat_headers = 1;
+	}
 }
 
 unsigned int x264Encoder::calculateBitrate(unsigned int fpsNum, unsigned int fpsDen, unsigned int frameCount, unsigned int sizeInMb)
