@@ -69,20 +69,21 @@ x264ConfigDialog::x264ConfigDialog(vidEncConfigParameters *configParameters, vid
 	connect(ui.quantiserSlider, SIGNAL(valueChanged(int)), this, SLOT(quantiserSlider_valueChanged(int)));
 	connect(ui.quantiserSpinBox, SIGNAL(valueChanged(int)), this, SLOT(quantiserSpinBox_valueChanged(int)));
 	connect(ui.targetRateControlSpinBox, SIGNAL(valueChanged(int)), this, SLOT(targetRateControlSpinBox_valueChanged(int)));
-
-#if X264_BUILD >= 69
+	connect(ui.maxCrfSlider, SIGNAL(valueChanged(int)), this, SLOT(maxCrfSlider_valueChanged(int)));
+	connect(ui.maxCrfSpinBox, SIGNAL(valueChanged(int)), this, SLOT(maxCrfSpinBox_valueChanged(int)));
 	connect(ui.mbTreeCheckBox, SIGNAL(toggled(bool)), this, SLOT(mbTreeCheckBox_toggled(bool)));
-#else
-	ui.mbTreeCheckBox->setVisible(false);
-	ui.lblLookahead->setVisible(false);
-	ui.lookaheadSpinBox->setVisible(false);
-	ui.lblLookaheadFrames->setVisible(false);
+
+#if X264_BUILD < 90
+	ui.maxCrfCheckBox->setVisible(false);
+	ui.quantiserLabel1_2->setVisible(false);
+	ui.quantiserLabel2_2->setVisible(false);
+	ui.quantiserLabel3_2->setVisible(false);
+	ui.maxCrfSlider->setVisible(false);
+	ui.maxCrfSpinBox->setVisible(false);
 #endif
 
-#if X264_BUILD < 75
-	ui.threadedLookaheadCheckBox->setVisible(false);
-	ui.threadedLookaheadSpinBox->setVisible(false);
-	ui.lblThreadedFrames->setVisible(false);
+#if X264_BUILD < 86
+	ui.fastFirstPassCheckBox->setVisible(false);
 #endif
 
 	ui.sarAsInputLabel->setText(QString("%1:%2").arg(properties->parWidth).arg(properties->parHeight));
@@ -93,35 +94,27 @@ x264ConfigDialog::x264ConfigDialog(vidEncConfigParameters *configParameters, vid
 	connect(ui.dct8x8CheckBox, SIGNAL(toggled(bool)), this, SLOT(dct8x8CheckBox_toggled(bool)));
 	connect(ui.p8x8CheckBox, SIGNAL(toggled(bool)), this, SLOT(p8x8CheckBox_toggled(bool)));
 
-	ui.scenecutDetectionCheckBox->setVisible(false);
-
-#if X264_BUILD < 79
-	ui.lblWeightedPPredict->setVisible(false);
-	ui.weightedPPredictComboBox->setVisible(false);
-#endif
-
 	// Frame tab
 	connect(ui.loopFilterCheckBox, SIGNAL(toggled(bool)), this, SLOT(loopFilterCheckBox_toggled(bool)));
-	connect(ui.cabacCheckBox, SIGNAL(toggled(bool)), this, SLOT(cabacCheckBox_toggled(bool)));
 
-#if X264_BUILD < 77
-	ui.constrainedIntraCheckBox->setVisible(false);
+#if X264_BUILD < 102
+	ui.openGopCheckBox->setVisible(false);
+	ui.openGopComboBox->setVisible(false);
 #endif
 
-#if X264_BUILD < 78
-	ui.bFrameRefComboBox->clear();
-	ui.bFrameRefComboBox->addItem(QT_TR_NOOP("Disabled"));
-	ui.bFrameRefComboBox->addItem(QT_TR_NOOP("Enabled"));
+#if X264_BUILD < 96
+	ui.interlacedComboBox->removeItem(2);
+#endif
+
+#if X264_BUILD < 89
+	ui.interlacedComboBox->removeItem(1);
 #endif
 
 	// Analysis tab
-	connect(ui.trellisCheckBox, SIGNAL(toggled(bool)), this, SLOT(trellisCheckBox_toggled(bool)));
 	connect(ui.matrixCustomEditButton, SIGNAL(pressed()), this, SLOT(matrixCustomEditButton_pressed()));
 
 	// Quantiser tab
-#if X264_BUILD >= 69
 	connect(ui.aqVarianceCheckBox, SIGNAL(toggled(bool)), this, SLOT(aqVarianceCheckBox_toggled(bool)));
-#endif
 
 	// Advanced tab
 	ui.zoneTableView->sortByColumn(0, Qt::AscendingOrder);
@@ -137,10 +130,6 @@ x264ConfigDialog::x264ConfigDialog(vidEncConfigParameters *configParameters, vid
 	connect(ui.zoneEditButton, SIGNAL(pressed()), this, SLOT(zoneEditButton_pressed()));
 	connect(ui.zoneDeleteButton, SIGNAL(pressed()), this, SLOT(zoneDeleteButton_pressed()));
 
-#if X264_BUILD < 73
-	ui.slicingGroupBox->setEnabled(false);
-#endif
-
 	QWidgetList widgetList = QApplication::allWidgets();
 
 	for (int widgetIndex = 0; widgetIndex < widgetList.size(); widgetIndex++)
@@ -166,10 +155,20 @@ x264ConfigDialog::x264ConfigDialog(vidEncConfigParameters *configParameters, vid
 		}
 	}
 
+#if X264_BUILD < 89
+	ui.hrdLabel->setVisible(false);
+	ui.hrdComboBox->setVisible(false);
+#endif
+
 	fillConfigurationComboBox();
 
 	if (!loadPresetSettings(encodeOptions, options))
 		loadSettings(encodeOptions, options);
+
+	// Expand to see all tabs but still allow the window to be resized smaller
+	 ui.tabWidget->setUsesScrollButtons(false);
+	 this->adjustSize();
+	 ui.tabWidget->setUsesScrollButtons(true);
 }
 
 void x264ConfigDialog::fillConfigurationComboBox(void)
@@ -196,8 +195,8 @@ void x264ConfigDialog::fillConfigurationComboBox(void)
 		configs.insert(QFileInfo(list[item]).completeBaseName(), PLUGIN_CONFIG_SYSTEM);
 
 	ui.configurationComboBox->clear();
-	ui.configurationComboBox->addItem(QT_TR_NOOP("<default>"), PLUGIN_CONFIG_DEFAULT);
-	ui.configurationComboBox->addItem(QT_TR_NOOP("<custom>"), PLUGIN_CONFIG_CUSTOM);
+	ui.configurationComboBox->addItem(tr("<default>"), PLUGIN_CONFIG_DEFAULT);
+	ui.configurationComboBox->addItem(tr("<custom>"), PLUGIN_CONFIG_CUSTOM);
 
 	QMap<QString, int>::const_iterator mapIterator = configs.constBegin();
 
@@ -324,7 +323,7 @@ void x264ConfigDialog::saveAsButton_pressed(void)
 
 	ADM_mkdir(configDirectory);
 
-	QString configFileName = QFileDialog::getSaveFileName(this, QT_TR_NOOP("Save As"), configDirectory, QT_TR_NOOP("x264 Configuration File (*.xml)"));
+	QString configFileName = QFileDialog::getSaveFileName(this, tr("Save As"), configDirectory, tr("x264 Configuration File (*.xml)"));
 
 	if (!configFileName.isNull())
 	{
@@ -359,7 +358,7 @@ void x264ConfigDialog::deleteButton_pressed(void)
 
 	delete [] configDir;
 
-	if (GUI_Question(QT_TR_NOOP("Are you sure you wish to delete the selected configuration?")) && configFile.exists())
+	if (GUI_Question(tr("Are you sure you wish to delete the selected configuration?").toUtf8().constData()) && configFile.exists())
 	{
 		disableGenericSlots = true;
 		configFile.remove();
@@ -372,44 +371,50 @@ void x264ConfigDialog::deleteButton_pressed(void)
 // General tab
 void x264ConfigDialog::encodingModeComboBox_currentIndexChanged(int index)
 {
-	bool enable = false;
+	bool enableQp = false, enableMaxCrf = false;
 
 	switch (index)
 	{
 		case 0:
-			ui.targetRateControlLabel1->setText(QT_TR_NOOP("Target Bitrate:"));
-			ui.targetRateControlLabel2->setText(QT_TR_NOOP("kbit/s"));
+			ui.targetRateControlLabel1->setText(tr("Target Bitrate:"));
+			ui.targetRateControlLabel2->setText(tr("kbit/s"));
 			ui.targetRateControlSpinBox->setValue(lastBitrate);
 			break;
 		case 1: // Constant Quality - 1 pass
-			ui.quantiserLabel2->setText(QT_TR_NOOP("Quantiser:"));
-			enable = true;
+			ui.quantiserLabel2->setText(tr("Quantiser:"));
+			enableQp = true;
 			break;
 		case 2: // Average Quantiser - 1 pass
-			ui.quantiserLabel2->setText(QT_TR_NOOP("Quality:"));
-			enable = true;
+			ui.quantiserLabel2->setText(tr("Quality:"));
+			enableQp = true;
+			enableMaxCrf = true;
 			break;
 		case 3: // Video Size - 2 pass
-			ui.targetRateControlLabel1->setText(QT_TR_NOOP("Target Video Size:"));
-			ui.targetRateControlLabel2->setText(QT_TR_NOOP("MB"));
+			ui.targetRateControlLabel1->setText(tr("Target Video Size:"));
+			ui.targetRateControlLabel2->setText(tr("MB"));
 			ui.targetRateControlSpinBox->setValue(lastVideoSize);
 			break;
 		case 4: // Average Bitrate - 2 pass
-			ui.targetRateControlLabel1->setText(QT_TR_NOOP("Average Bitrate:"));
-			ui.targetRateControlLabel2->setText(QT_TR_NOOP("kbit/s"));
+			ui.targetRateControlLabel1->setText(tr("Average Bitrate:"));
+			ui.targetRateControlLabel2->setText(tr("kbit/s"));
 			ui.targetRateControlSpinBox->setValue(lastBitrate);
 			break;
 	}
 
-	ui.quantiserLabel1->setEnabled(enable);
-	ui.quantiserLabel2->setEnabled(enable);
-	ui.quantiserLabel3->setEnabled(enable);
-	ui.quantiserSlider->setEnabled(enable);
-	ui.quantiserSpinBox->setEnabled(enable);
+	ui.quantiserLabel1->setEnabled(enableQp);
+	ui.quantiserLabel2->setEnabled(enableQp);
+	ui.quantiserLabel3->setEnabled(enableQp);
+	ui.quantiserSlider->setEnabled(enableQp);
+	ui.quantiserSpinBox->setEnabled(enableQp);
 
-	ui.targetRateControlLabel1->setEnabled(!enable);
-	ui.targetRateControlLabel2->setEnabled(!enable);
-	ui.targetRateControlSpinBox->setEnabled(!enable);
+	ui.targetRateControlLabel1->setEnabled(!enableQp);
+	ui.targetRateControlLabel2->setEnabled(!enableQp);
+	ui.targetRateControlSpinBox->setEnabled(!enableQp);
+
+	if (!enableMaxCrf)
+		ui.maxCrfCheckBox->setChecked(false);
+
+	ui.maxCrfCheckBox->setEnabled(enableMaxCrf);
 }
 
 void x264ConfigDialog::quantiserSlider_valueChanged(int value)
@@ -430,18 +435,26 @@ void x264ConfigDialog::targetRateControlSpinBox_valueChanged(int value)
 		lastBitrate = value;
 }
 
-#if X264_BUILD >= 69
+void x264ConfigDialog::maxCrfSlider_valueChanged(int value)
+{
+	ui.maxCrfSpinBox->setValue(value);
+}
+
+void x264ConfigDialog::maxCrfSpinBox_valueChanged(int value)
+{
+	ui.maxCrfSlider->setValue(value);
+}
+
 void x264ConfigDialog::mbTreeCheckBox_toggled(bool checked)
 {
 	if (!disableGenericSlots && checked && !ui.aqVarianceCheckBox->isChecked())
 	{
-		if (GUI_Question(QT_TR_NOOP("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?")))
+		if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?").toUtf8().constData()))
 			ui.aqVarianceCheckBox->setChecked(true);
 		else
 			ui.mbTreeCheckBox->setChecked(false);
 	}
 }
-#endif
 
 // Motion Estimation tab
 void x264ConfigDialog::meSlider_valueChanged(int value)
@@ -479,29 +492,6 @@ void x264ConfigDialog::loopFilterCheckBox_toggled(bool checked)
 	}
 }
 
-void x264ConfigDialog::cabacCheckBox_toggled(bool checked)
-{
-	if (!disableGenericSlots && !checked && ui.trellisCheckBox->isChecked())
-	{
-		if (GUI_Question(QT_TR_NOOP("Trellis optimisation isn't possible without CABAC coding enabled.  Trellis optimisation will automatically be disabled.\n\n Do you wish to continue?")))
-			ui.trellisCheckBox->setChecked(false);
-		else
-			ui.cabacCheckBox->setChecked(true);
-	}
-}
-
-// Analysis tab
-void x264ConfigDialog::trellisCheckBox_toggled(bool checked)
-{
-	if (!disableGenericSlots && checked && !ui.cabacCheckBox->isChecked())
-	{
-		if (GUI_Question(QT_TR_NOOP("Trellis optimisation requires CABAC coding to be enabled.  CABAC coding will automatically be enabled.\n\nDo you wish to continue?")))
-			ui.cabacCheckBox->setChecked(true);
-		else
-			ui.trellisCheckBox->setChecked(false);
-	}
-}
-
 void x264ConfigDialog::matrixCustomEditButton_pressed()
 {
 	x264CustomMatrixDialog dialog(this, intra4x4Luma, intraChroma, inter4x4Luma, interChroma, intra8x8Luma, inter8x8Luma);
@@ -514,18 +504,16 @@ void x264ConfigDialog::matrixCustomEditButton_pressed()
 }
 
 // Quantiser tab
-#if X264_BUILD >= 69
 void x264ConfigDialog::aqVarianceCheckBox_toggled(bool checked)
 {
 	if (!disableGenericSlots && !checked && ui.mbTreeCheckBox->isChecked())
 	{
-		if (GUI_Question(QT_TR_NOOP("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?")))
+		if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?").toUtf8().constData()))
 			ui.mbTreeCheckBox->setChecked(false);
 		else
 			ui.aqVarianceCheckBox->setChecked(true);
 	}
 }
-#endif
 
 // Advanced tab
 void x264ConfigDialog::zoneAddButton_pressed()
@@ -544,7 +532,7 @@ void x264ConfigDialog::zoneEditButton_pressed()
 
 void x264ConfigDialog::zoneDeleteButton_pressed()
 {
-	if (ui.zoneTableView->currentIndex().row() >= 0 && GUI_Question(QT_TR_NOOP("Are you sure you wish to delete the selected zone?")))
+	if (ui.zoneTableView->currentIndex().row() >= 0 && GUI_Question(tr("Are you sure you wish to delete the selected zone?").toUtf8().constData()))
 	{
 		zoneTableModel.removeRows(ui.zoneTableView->currentIndex().row(), 1, QModelIndex());
 		ui.configurationComboBox->setCurrentIndex(1);
@@ -608,6 +596,9 @@ bool x264ConfigDialog::loadPresetSettings(vidEncOptions *encodeOptions, x264Opti
 void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *options)
 {
 	bool origDisableGenericSlots = disableGenericSlots;
+#if X264_BUILD > 89
+	unsigned int maxCrf = options->getMaximumConstantRateFactor();
+#endif
 
 	disableGenericSlots = true;
 
@@ -625,6 +616,17 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 		case ADM_VIDENC_MODE_AQP:	// Average Quantizer (Single Pass)
 			ui.encodingModeComboBox->setCurrentIndex(2);
 			ui.quantiserSpinBox->setValue(encodeOptions->encodeModeParameter);
+
+#if X264_BUILD > 89
+			if (maxCrf == 0)
+				ui.maxCrfCheckBox->setChecked(false);
+			else
+			{
+				ui.maxCrfCheckBox->setChecked(true);
+				ui.maxCrfSlider->setValue(maxCrf);
+			}
+#endif
+
 			break;
 		case ADM_VIDENC_MODE_2PASS_SIZE:	// Video Size (Two Pass)
 			ui.encodingModeComboBox->setCurrentIndex(3);
@@ -636,10 +638,11 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 			break;
 	}
 
-#if X264_BUILD >= 69
 	ui.mbTreeCheckBox->setChecked(options->getMbTree());
-	ui.lookaheadSpinBox->setValue(options->getFrametypeLookahead());
+#if X264_BUILD > 85
+	ui.fastFirstPassCheckBox->setChecked(options->getFastFirstPass());
 #endif
+	ui.lookaheadSpinBox->setValue(options->getFrametypeLookahead());
 
 	if (options->getSarAsInput())
 		ui.sarAsInputRadioButton->setChecked(true);
@@ -679,14 +682,15 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 			ui.threadCustomSpinBox->setValue(options->getThreads());
 	}
 
-#if X264_BUILD >= 75
+	ui.repeatabilityCheckBox->setChecked(options->getDeterministic());
+	ui.sliceThreadingCheckBox->setChecked(options->getSliceThreading());
+
 	int threadedLookahead = options->getThreadedLookahead();
 
 	ui.threadedLookaheadCheckBox->setChecked(threadedLookahead > -1);
 
 	if (threadedLookahead > -1)
 		ui.threadedLookaheadSpinBox->setValue(threadedLookahead);
-#endif
 
 	// Motion Estimation tab
 	ui.meSpinBox->setValue(options->getSubpixelRefinement());
@@ -711,10 +715,7 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	ui.predictModeComboBox->setCurrentIndex(options->getDirectPredictionMode());
 
-#if X264_BUILD >= 79
 	ui.weightedPPredictComboBox->setCurrentIndex(options->getWeightedPredictionPFrames());
-#endif
-
 	ui.weightedPredictCheckBox->setChecked(options->getWeightedPrediction());
 
 	// Partition tab
@@ -728,12 +729,27 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	// Frame tab
 	ui.cabacCheckBox->setChecked(options->getCabac());
-	ui.interlacedCheckBox->setChecked(options->getInterlaced());
 
-#if X264_BUILD >= 77
-	ui.constrainedIntraCheckBox->setChecked(options->getConstrainedIntraPrediction());
+#if X264_BUILD > 101
+	if (options->getOpenGopMode())
+	{
+		ui.openGopCheckBox->setChecked(true);
+		ui.openGopComboBox->setCurrentIndex(options->getOpenGopMode() - 1);
+	}
+	else
+		ui.openGopCheckBox->setChecked(false);
 #endif
 
+	if (options->getInterlaced() > 0)
+	{
+		ui.interlacedCheckBox->setChecked(true);
+		ui.interlacedComboBox->setCurrentIndex(options->getInterlaced() - 1);
+	}
+	else
+		ui.interlacedCheckBox->setChecked(false);
+
+	ui.constrainedIntraCheckBox->setChecked(options->getConstrainedIntraPrediction());
+
 	ui.loopFilterCheckBox->setChecked(options->getLoopFilter());
 	ui.alphaC0SpinBox->setValue(options->getLoopFilterAlphaC0());
 	ui.betaSpinBox->setValue(options->getLoopFilterBeta());
@@ -745,6 +761,7 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 	ui.maxGopSizeSpinBox->setValue(options->getGopMaximumSize());
 	ui.minGopSizeSpinBox->setValue(options->getGopMinimumSize());
 	ui.IFrameThresholdSpinBox->setValue(options->getScenecutThreshold());
+	ui.intraRefreshCheckBox->setChecked(options->getIntraRefresh());
 
 	// Analysis tab
 	ui.mixedRefsCheckBox->setChecked(options->getMixedReferences());
@@ -805,11 +822,9 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 	ui.vbvBufferSizeSpinBox->setValue(options->getVbvBufferSize());
 	ui.vbvBufferOccupancySpinBox->setValue((int)floor(options->getVbvInitialOccupancy() * 100 + .5));
 
-#if X264_BUILD >= 73
 	ui.maxSliceSizeSpinBox->setValue(options->getSliceMaxSize());
 	ui.maxSliceMbSpinBox->setValue(options->getSliceMaxMacroblocks());
 	ui.slicesPerFrameSpinBox->setValue(options->getSliceCount());
-#endif
 
 	zoneTableModel.removeRows();
 
@@ -834,7 +849,6 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	strSpsId.setNum(options->getSpsIdentifier());
 	ui.spsiComboBox->setCurrentIndex(ui.spsiComboBox->findText(strSpsId));
-	ui.repeatabilityCheckBox->setChecked(options->getDeterministic());
 	ui.accessUnitCheckBox->setChecked(options->getAccessUnitDelimiters());
 	ui.overscanComboBox->setCurrentIndex(options->getOverscan());
 	ui.videoFormatComboBox->setCurrentIndex(getValueIndexInArray(options->getVideoFormat(), videoFormat, videoFormatCount));
@@ -843,6 +857,9 @@ void x264ConfigDialog::loadSettings(vidEncOptions *encodeOptions, x264Options *o
 	ui.colourMatrixComboBox->setCurrentIndex(getValueIndexInArray(options->getColorMatrix(), colourMatrix, colourMatrixCount));
 	ui.chromaSampleSpinBox->setValue(options->getChromaSampleLocation());
 	ui.fullRangeSamplesCheckBox->setChecked(options->getFullRangeSamples());
+#if X264_BUILD > 88
+	ui.hrdComboBox->setCurrentIndex(options->getHrdParameter());
+#endif
 
 	disableGenericSlots = origDisableGenericSlots;
 }
@@ -880,11 +897,18 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	options->setPresetConfiguration(ui.configurationComboBox->currentText().toUtf8().constData(), configurationType);
 
-#if X264_BUILD >= 69
-	options->setMbTree(ui.mbTreeCheckBox->isChecked());
-	options->setFrametypeLookahead(ui.lookaheadSpinBox->value());
+#if X264_BUILD > 89
+	if (ui.encodingModeComboBox->currentIndex() == 2 && ui.maxCrfCheckBox->isChecked())
+		options->setMaximumConstantRateFactor(ui.maxCrfSlider->value());
+	else
+		options->setMaximumConstantRateFactor(0);
 #endif
 
+	options->setMbTree(ui.mbTreeCheckBox->isChecked());
+#if X264_BUILD > 85
+	options->setFastFirstPass(ui.fastFirstPassCheckBox->isChecked());
+#endif
+	options->setFrametypeLookahead(ui.lookaheadSpinBox->value());
 	options->setSarAsInput(ui.sarAsInputRadioButton->isChecked());
 
 	if (ui.sarCustomRadioButton->isChecked())
@@ -911,12 +935,13 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	else
 		options->setThreads(ui.threadCustomSpinBox->value());
 
-#if X264_BUILD >= 75
+	options->setSliceThreading(ui.sliceThreadingCheckBox->isChecked());
+	options->setDeterministic(ui.repeatabilityCheckBox->isChecked());
+
 	if (ui.threadedLookaheadCheckBox->isChecked())
 		options->setThreadedLookahead(ui.threadedLookaheadSpinBox->value());
 	else
 		options->setThreadedLookahead(-1);
-#endif
 
 	// Motion Estimation tab
 	options->setSubpixelRefinement(ui.meSpinBox->value());
@@ -935,10 +960,7 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	options->setDirectPredictionMode(ui.predictModeComboBox->currentIndex());
 
-#if X264_BUILD >= 79
 	options->setWeightedPredictionPFrames(ui.weightedPPredictComboBox->currentIndex());
-#endif
-
 	options->setWeightedPrediction(ui.weightedPredictCheckBox->isChecked());
 	options->setDct8x8(ui.dct8x8CheckBox->isChecked());
 	options->setPartitionP8x8(ui.p8x8CheckBox->isChecked());
@@ -949,12 +971,20 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 
 	// Frame tab
 	options->setCabac(ui.cabacCheckBox->isChecked());
-	options->setInterlaced(ui.interlacedCheckBox->isChecked());
 
-#if X264_BUILD >= 77
-	options->setConstrainedIntraPrediction(ui.constrainedIntraCheckBox->isChecked());
+#if X264_BUILD > 101
+	if (ui.openGopCheckBox->isChecked())
+		options->setOpenGopMode(ui.openGopComboBox->currentIndex() + 1);
+	else
+		options->setOpenGopMode(0);
 #endif
 
+	if (ui.interlacedCheckBox->isChecked())
+		options->setInterlaced(ui.interlacedComboBox->currentIndex() + 1);
+	else
+		options->setInterlaced(0);
+
+	options->setConstrainedIntraPrediction(ui.constrainedIntraCheckBox->isChecked());
 	options->setLoopFilter(ui.loopFilterCheckBox->isChecked());
 	options->setLoopFilterAlphaC0(ui.alphaC0SpinBox->value());
 	options->setLoopFilterBeta(ui.betaSpinBox->value());
@@ -966,6 +996,7 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	options->setGopMaximumSize(ui.maxGopSizeSpinBox->value());
 	options->setGopMinimumSize(ui.minGopSizeSpinBox->value());
 	options->setScenecutThreshold(ui.IFrameThresholdSpinBox->value());
+	options->setIntraRefresh(ui.intraRefreshCheckBox->isChecked());
 
 	// Analysis tab
 	options->setMixedReferences(ui.mixedRefsCheckBox->isChecked());
@@ -1022,12 +1053,9 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	options->setVbvMaximumBitrate(ui.vbvMaxBitrateSpinBox->value());
 	options->setVbvBufferSize(ui.vbvBufferSizeSpinBox->value());
 	options->setVbvInitialOccupancy((float)ui.vbvBufferOccupancySpinBox->value() / 100);
-
-#if X264_BUILD >= 73
 	options->setSliceMaxSize(ui.maxSliceSizeSpinBox->value());
 	options->setSliceMaxMacroblocks(ui.maxSliceMbSpinBox->value());
 	options->setSliceCount(ui.slicesPerFrameSpinBox->value());
-#endif
 
 	options->clearZones();
 
@@ -1039,7 +1067,6 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	// Output tab
 	options->setIdcLevel(idcLevel[ui.idcLevelComboBox->currentIndex()]);
 	options->setSpsIdentifier(ui.spsiComboBox->currentText().toInt());
-	options->setDeterministic(ui.repeatabilityCheckBox->isChecked());
 	options->setAccessUnitDelimiters(ui.accessUnitCheckBox->isChecked());
 	options->setOverscan(ui.overscanComboBox->currentIndex());
 	options->setVideoFormat(videoFormat[ui.videoFormatComboBox->currentIndex()]);
@@ -1048,6 +1075,9 @@ void x264ConfigDialog::saveSettings(vidEncOptions *encodeOptions, x264Options *o
 	options->setColorMatrix(colourMatrix[ui.colourMatrixComboBox->currentIndex()]);
 	options->setChromaSampleLocation(ui.chromaSampleSpinBox->value());
 	options->setFullRangeSamples(ui.fullRangeSamplesCheckBox->isChecked());
+#if X264_BUILD > 88
+	options->setHrdParameter(ui.hrdComboBox->currentIndex());
+#endif
 }
 
 extern "C" int showX264ConfigDialog(vidEncConfigParameters *configParameters, vidEncVideoProperties *properties, vidEncOptions *encodeOptions, x264Options *options)
