@@ -52,9 +52,12 @@ void x264Options::reset(void)
 	x264_param_default(&_param);
 	_param.vui.i_sar_height = 1;
 	_param.vui.i_sar_width = 1;
-	_param.i_threads = 0;	// set to auto-detect; default is disabled
 
 	_sarAsInput = false;
+
+#if X264_BUILD > 85
+	_fastFirstPast = true;
+#endif
 }
 
 x264_param_t* x264Options::getParameters(void)
@@ -75,6 +78,18 @@ x264_param_t* x264Options::getParameters(void)
 	return param;
 }
 
+#if X264_BUILD > 85
+bool x264Options::getFastFirstPass(void)
+{
+	return _fastFirstPast;
+}
+
+void x264Options::setFastFirstPass(bool fastFirstPass)
+{
+	_fastFirstPast = fastFirstPass;
+}
+#endif
+
 int x264Options::getThreads(void)
 {
 	return _param.i_threads;
@@ -96,7 +111,16 @@ void x264Options::setDeterministic(bool deterministic)
 	_param.b_deterministic = deterministic;
 }
 
-#if X264_BUILD >= 75
+bool x264Options::getSliceThreading(void)
+{
+	return _param.b_sliced_threads;
+}
+
+void x264Options::setSliceThreading(bool sliceThreading)
+{
+	_param.b_sliced_threads = sliceThreading;
+}
+
 int x264Options::getThreadedLookahead(void)
 {
 	return _param.i_sync_lookahead;
@@ -107,7 +131,6 @@ void x264Options::setThreadedLookahead(int frames)
 	if (frames >= -1 && frames <= 250)
 		_param.i_sync_lookahead = frames;
 }
-#endif
 
 int x264Options::getIdcLevel(void)
 {
@@ -268,11 +291,21 @@ void x264Options::setGopMinimumSize(unsigned int gopSize)
 
 unsigned int x264Options::getGopMaximumSize(void)
 {
+#if X264_BUILD > 101
+	if (_param.i_keyint_max == X264_KEYINT_MAX_INFINITE)
+		return 0;
+	else
+#endif
 	return _param.i_keyint_max;
 }
 
 void x264Options::setGopMaximumSize(unsigned int gopSize)
 {
+#if X264_BUILD > 101
+	if (gopSize == 0)
+		_param.i_keyint_max = X264_KEYINT_MAX_INFINITE;
+	else
+#endif
 	if (gopSize <= 1000)
 		_param.i_keyint_max = gopSize;
 }
@@ -288,6 +321,16 @@ void x264Options::setScenecutThreshold(unsigned int scenecutThreshold)
 		_param.i_scenecut_threshold = scenecutThreshold;
 }
 
+bool x264Options::getIntraRefresh(void)
+{
+	return _param.b_intra_refresh;
+}
+
+void x264Options::setIntraRefresh(bool intraRefresh)
+{
+	_param.b_intra_refresh = intraRefresh;
+}
+
 unsigned int x264Options::getBFrames(void)
 {
 	return _param.i_bframe;
@@ -323,21 +366,13 @@ void x264Options::setBFrameBias(int bFrameBias)
 
 unsigned int x264Options::getBFrameReferences(void)
 {
-#if X264_BUILD >= 78
 	return _param.i_bframe_pyramid;
-#else
-	return _param.b_bframe_pyramid;
-#endif
 }
 
 void x264Options::setBFrameReferences(unsigned int bFrameReferences)
 {
-#if X264_BUILD >= 78
 	if (bFrameReferences <= 2)
 		_param.i_bframe_pyramid = bFrameReferences;
-#else
-	_param.b_bframe_pyramid = !!bFrameReferences;
-#endif
 }
 
 bool x264Options::getLoopFilter(void)
@@ -382,17 +417,56 @@ void x264Options::setCabac(bool cabac)
 	_param.b_cabac = cabac;
 }
 
-bool x264Options::getInterlaced(void)
+#if X264_BUILD > 101
+unsigned int x264Options::getOpenGopMode(void)
 {
+	return _param.i_open_gop;
+}
+
+void x264Options::setOpenGopMode(unsigned int openGopMode)
+{
+	if (openGopMode < 3)
+		_param.i_open_gop = openGopMode;
+}
+#endif
+
+unsigned int x264Options::getInterlaced(void)
+{
+#if X264_BUILD > 88
+	if (_param.b_interlaced)
+	{
+		if (_param.b_tff)
+			return 2;
+		else
+			return 1;
+	}
+	else
+	{
+#	if X264_BUILD > 95
+		if (_param.b_fake_interlaced)
+			return 3;
+		else
+#endif
+			return 0;
+	}
+#else
 	return _param.b_interlaced;
+#endif
 }
 
-void x264Options::setInterlaced(bool interlaced)
+void x264Options::setInterlaced(unsigned int interlaced)
 {
-	_param.b_interlaced = interlaced;
+	_param.b_interlaced = (interlaced == 1 || interlaced == 2);
+
+#if X264_BUILD > 88
+	_param.b_tff = (interlaced == 2 ? 1 : 0);
+#endif
+
+#if X264_BUILD > 95
+	_param.b_fake_interlaced = (interlaced == 3 ? 1 : 0);
+#endif
 }
 
-#if X264_BUILD >= 77
 bool x264Options::getConstrainedIntraPrediction(void)
 {
 	return _param.b_constrained_intra;
@@ -402,7 +476,6 @@ void x264Options::setConstrainedIntraPrediction(bool constrainedIntra)
 {
 	_param.b_constrained_intra = constrainedIntra;
 }
-#endif
 
 unsigned int x264Options::getCqmPreset(void)
 {
@@ -550,7 +623,6 @@ void x264Options::setDct8x8(bool dct8x8)
 	_param.analyse.b_transform_8x8 = dct8x8;
 }
 
-#if X264_BUILD >= 79
 unsigned int x264Options::getWeightedPredictionPFrames(void)
 {
 	return _param.analyse.i_weighted_pred;
@@ -560,7 +632,6 @@ void x264Options::setWeightedPredictionPFrames(unsigned int weightedPrediction)
 {
 	_param.analyse.i_weighted_pred = weightedPrediction;
 }
-#endif
 
 bool x264Options::getWeightedPrediction(void)
 {
@@ -776,6 +847,19 @@ void x264Options::setQuantiserStep(unsigned int quantiserStep)
 		_param.rc.i_qp_step = quantiserStep;
 }
 
+#if X264_BUILD > 89
+unsigned int x264Options::getMaximumConstantRateFactor(void)
+{
+	return (unsigned int)_param.rc.f_rf_constant_max;
+}
+
+void x264Options::setMaximumConstantRateFactor(unsigned int maxCrf)
+{
+	if (maxCrf <= 51)
+		_param.rc.f_rf_constant_max = maxCrf;
+}
+#endif
+
 float x264Options::getAverageBitrateTolerance(void)
 {
 	return _param.rc.f_rate_tolerance;
@@ -863,7 +947,6 @@ void x264Options::setAdaptiveQuantiserStrength(float adaptiveQuantiserStrength)
 	_param.rc.f_aq_strength = adaptiveQuantiserStrength;
 }
 
-#if X264_BUILD >= 69
 bool x264Options::getMbTree(void)
 {
 	return _param.rc.b_mb_tree;
@@ -884,7 +967,6 @@ void x264Options::setFrametypeLookahead(unsigned int frames)
 	if (frames <= 250)
 		_param.rc.i_lookahead = frames;
 }
-#endif
 
 float x264Options::getQuantiserCurveCompression(void)
 {
@@ -979,7 +1061,6 @@ void x264Options::setSpsIdentifier(unsigned int spsIdentifier)
 	}
 }
 
-#if X264_BUILD >= 73
 unsigned int x264Options::getSliceMaxSize(void)
 {
 	return _param.i_slice_max_size;
@@ -1009,6 +1090,18 @@ void x264Options::setSliceCount(unsigned int sliceCount)
 {
 	_param.i_slice_count = sliceCount;
 }
+
+#if X264_BUILD > 88
+unsigned int x264Options::getHrdParameter(void)
+{
+	return _param.i_nal_hrd;
+}
+
+void x264Options::setHrdParameter(unsigned int hrdParameter)
+{
+	if (hrdParameter <= 2)
+		_param.i_nal_hrd = hrdParameter;
+}
 #endif
 
 void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
@@ -1018,11 +1111,13 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	xmlNodePtr xmlNodeChild, xmlNodeChild2;
 
 	xmlNodeRoot = xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)getOptionsTagRoot(), NULL);
+#if X264_BUILD > 85
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"fastFirstPass", boolean2String(xmlBuffer, bufferSize, getFastFirstPass()));
+#endif
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"threads", number2String(xmlBuffer, bufferSize, getThreads()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"deterministic", boolean2String(xmlBuffer, bufferSize, getDeterministic()));
-#if X264_BUILD >= 75
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"sliceThreading", boolean2String(xmlBuffer, bufferSize, getSliceThreading()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"threadedLookahead", number2String(xmlBuffer, bufferSize, getThreadedLookahead()));
-#endif
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"idcLevel", number2String(xmlBuffer, bufferSize, getIdcLevel()));
 
 	xmlNodeChild = xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"vui", NULL);
@@ -1164,11 +1259,11 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"gopMaximumSize", number2String(xmlBuffer, bufferSize, getGopMaximumSize()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"gopMinimumSize", number2String(xmlBuffer, bufferSize, getGopMinimumSize()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"scenecutThreshold", number2String(xmlBuffer, bufferSize, getScenecutThreshold()));
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"periodicIntraRefresh", boolean2String(xmlBuffer, bufferSize, getIntraRefresh()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"bFrames", number2String(xmlBuffer, bufferSize, getBFrames()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"adaptiveBframeDecision", number2String(xmlBuffer, bufferSize, getAdaptiveBFrameDecision()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"bFrameBias", number2String(xmlBuffer, bufferSize, getBFrameBias()));
 
-#if X264_BUILD >= 78
 	switch (getBFrameReferences())
 	{
 		case 0:
@@ -1183,20 +1278,49 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	}
 
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"bFrameReferences", xmlBuffer);
-#else
-	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"bFrameReferences", boolean2String(xmlBuffer, bufferSize, (bool)getBFrameReferences()));
-#endif
-
-
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"loopFilter", boolean2String(xmlBuffer, bufferSize, getLoopFilter()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"loopFilterAlphaC0", number2String(xmlBuffer, bufferSize, getLoopFilterAlphaC0()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"loopFilterBeta", number2String(xmlBuffer, bufferSize, getLoopFilterBeta()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"cabac", boolean2String(xmlBuffer, bufferSize, getCabac()));
-	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"interlaced", boolean2String(xmlBuffer, bufferSize, getInterlaced()));
-#if X264_BUILD >= 77
-	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"constrainedIntraPrediction", boolean2String(xmlBuffer, bufferSize, getConstrainedIntraPrediction()));
+
+#if X264_BUILD > 101
+	switch (getOpenGopMode())
+	{
+		case 1:
+			strcpy((char*)xmlBuffer, "normal");
+			break;
+		case 2:
+			strcpy((char*)xmlBuffer, "bluray");
+			break;
+		default:
+			strcpy((char*)xmlBuffer, "disabled");
+			break;
+	}
+
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"openGop", xmlBuffer);
 #endif
 
+	switch (getInterlaced())
+	{
+		case 1:
+			strcpy((char*)xmlBuffer, "bff");
+			break;
+		case 2:
+			strcpy((char*)xmlBuffer, "tff");
+			break;
+#if X264_BUILD > 95
+		case 3:
+			strcpy((char*)xmlBuffer, "fake");
+			break;
+#endif
+		default:
+			strcpy((char*)xmlBuffer, "disabled");
+			break;
+	}
+
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"interlaced", xmlBuffer);
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"constrainedIntraPrediction", boolean2String(xmlBuffer, bufferSize, getConstrainedIntraPrediction()));
+
 	switch (getCqmPreset())
 	{
 		case X264_CQM_FLAT:
@@ -1257,7 +1381,6 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"partitionB8x8", boolean2String(xmlBuffer, bufferSize, getPartitionB8x8()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"dct8x8", boolean2String(xmlBuffer, bufferSize, getDct8x8()));
 
-#if X264_BUILD >= 79
 	switch (getWeightedPredictionPFrames())
 	{
 		case X264_WEIGHTP_NONE:
@@ -1272,8 +1395,6 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	}
 
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"weightedPredictionPframes", xmlBuffer);
-#endif
-
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"weightedPrediction", boolean2String(xmlBuffer, bufferSize, getWeightedPrediction()));
 
 	switch (getDirectPredictionMode())
@@ -1348,6 +1469,9 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"quantiserMinimum", number2String(xmlBuffer, bufferSize, getQuantiserMinimum()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"quantiserMaximum", number2String(xmlBuffer, bufferSize, getQuantiserMaximum()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"quantiserStep", number2String(xmlBuffer, bufferSize, getQuantiserStep()));
+#if X264_BUILD > 89
+	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"maximumConstantRateFactor", number2String(xmlBuffer, bufferSize, getMaximumConstantRateFactor()));
+#endif
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"averageBitrateTolerance", number2String(xmlBuffer, bufferSize, getAverageBitrateTolerance()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"vbvMaximumBitrate", number2String(xmlBuffer, bufferSize, getVbvMaximumBitrate()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"vbvBufferSize", number2String(xmlBuffer, bufferSize, getVbvBufferSize()));
@@ -1367,12 +1491,8 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"adaptiveQuantiserMode", xmlBuffer);
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"adaptiveQuantiserStrength", number2String(xmlBuffer, bufferSize, getAdaptiveQuantiserStrength()));
-
-#if X264_BUILD >= 69
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"mbTree", boolean2String(xmlBuffer, bufferSize, getMbTree()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"frametypeLookahead", number2String(xmlBuffer, bufferSize, getFrametypeLookahead()));
-#endif
-
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"quantiserCurveCompression", number2String(xmlBuffer, bufferSize, getQuantiserCurveCompression()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"reduceFluxBeforeCurveCompression", number2String(xmlBuffer, bufferSize, getReduceFluxBeforeCurveCompression()));
 	xmlNewChild(xmlNodeChild, NULL, (xmlChar*)"reduceFluxAfterCurveCompression", number2String(xmlBuffer, bufferSize, getReduceFluxAfterCurveCompression()));
@@ -1404,11 +1524,25 @@ void x264Options::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"accessUnitDelimiters", boolean2String(xmlBuffer, bufferSize, getAccessUnitDelimiters()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"spsIdentifier", number2String(xmlBuffer, bufferSize, getSpsIdentifier()));
-
-#if X264_BUILD >= 73
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"sliceMaxSize", number2String(xmlBuffer, bufferSize, getSliceMaxSize()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"sliceMaxMacroblocks", number2String(xmlBuffer, bufferSize, getSliceMaxMacroblocks()));
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"sliceCount", number2String(xmlBuffer, bufferSize, getSliceCount()));
+
+#if X264_BUILD > 88
+	switch (getHrdParameter())
+	{
+		case X264_NAL_HRD_VBR:
+			strcpy((char*)xmlBuffer, "vbr");
+			break;
+		case X264_NAL_HRD_CBR:
+			strcpy((char*)xmlBuffer, "cbr");
+			break;
+		default:
+			strcpy((char*)xmlBuffer, "none");
+			break;
+	}
+
+	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"hrd", xmlBuffer);
 #endif
 }
 
@@ -1429,12 +1563,16 @@ void x264Options::parseOptions(xmlNode *node)
 
 			if (strcmp((char*)xmlChild->name, "threads") == 0)
 				setThreads(atoi(content));
+#if X264_BUILD > 85
+			else if (strcmp((char*)xmlChild->name, "fastFirstPass") == 0)
+				setFastFirstPass(string2Boolean(content));
+#endif
 			else if (strcmp((char*)xmlChild->name, "deterministic") == 0)
 				setDeterministic(string2Boolean(content));
-#if X264_BUILD >= 75
+			else if (strcmp((char*)xmlChild->name, "sliceThreading") == 0)
+				setSliceThreading(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "threadedLookahead") == 0)
 				setThreadedLookahead(atoi(content));
-#endif
 			else if (strcmp((char*)xmlChild->name, "idcLevel") == 0)
 				setIdcLevel(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "vui") == 0)
@@ -1447,6 +1585,8 @@ void x264Options::parseOptions(xmlNode *node)
 				setGopMinimumSize(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "scenecutThreshold") == 0)
 				setScenecutThreshold(atoi(content));
+			else if (strcmp((char*)xmlChild->name, "periodicIntraRefresh") == 0)
+				setIntraRefresh(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "bFrames") == 0)
 				setBFrames(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "adaptiveBframeDecision") == 0)
@@ -1460,11 +1600,7 @@ void x264Options::parseOptions(xmlNode *node)
 				if (strcmp(content, "strict") == 0)
 					bFrameReferences = 1;
 				else if (strcmp(content, "normal") == 0 || strcmp(content, "1") == 0 || strcmp(content, "true") == 0)
-#if X264_BUILD >= 78
 					bFrameReferences = 2;
-#else
-					bFrameReferences = 1;
-#endif
 
 				setBFrameReferences(bFrameReferences);
 			}
@@ -1476,12 +1612,34 @@ void x264Options::parseOptions(xmlNode *node)
 				setLoopFilterBeta(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "cabac") == 0)
 				setCabac(string2Boolean(content));
+#if X264_BUILD > 101
+			else if (strcmp((char*)xmlChild->name, "openGop") == 0)
+			{
+				int openGop = 0;
+
+				if (strcmp(content, "normal") == 0)
+					openGop = 1;
+				else if (strcmp(content, "bluray") == 0)
+					openGop = 2;
+
+				setOpenGopMode(openGop);
+			}
+#endif
 			else if (strcmp((char*)xmlChild->name, "interlaced") == 0)
-				setInterlaced(string2Boolean(content));
-#if X264_BUILD >= 77
+			{
+				int interlaced = 0;
+
+				if (strcmp(content, "bff") == 0)
+					interlaced = 1;
+				else if (strcmp(content, "tff") == 0)
+					interlaced = 2;
+				else if (strcmp(content, "fake") == 0)
+					interlaced = 3;
+
+				setInterlaced(interlaced);
+			}
 			else if (strcmp((char*)xmlChild->name, "constrainedIntraPrediction") == 0)
 				setConstrainedIntraPrediction(string2Boolean(content));
-#endif
 			else if (strcmp((char*)xmlChild->name, "cqmPreset") == 0)
 			{
 				int cqmPreset = 0;
@@ -1545,13 +1703,24 @@ void x264Options::parseOptions(xmlNode *node)
 				setAccessUnitDelimiters(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "spsIdentifier") == 0)
 				setSpsIdentifier(atoi(content));
-#if X264_BUILD >= 73
 			else if (strcmp((char*)xmlChild->name, "sliceMaxSize") == 0)
 				setSliceMaxSize(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "sliceMaxMacroblocks") == 0)
 				setSliceMaxMacroblocks(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "sliceCount") == 0)
 				setSliceCount(atoi(content));
+#if X264_BUILD > 88
+			else if (strcmp((char*)xmlChild->name, "hrd") == 0)
+			{
+				unsigned int hdr = X264_NAL_HRD_NONE;
+
+				if (strcmp(content, "vbr") == 0)
+					hdr = X264_NAL_HRD_VBR;
+				else if (strcmp(content, "cbr") == 0)
+					hdr = X264_NAL_HRD_CBR;
+
+				setHrdParameter(hdr);
+			}
 #endif
 
 			xmlFree(content);
@@ -1722,7 +1891,6 @@ void x264Options::parseAnalyseOptions(xmlNode *node)
 				setPartitionB8x8(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "dct8x8") == 0)
 				setDct8x8(string2Boolean(content));
-#if X264_BUILD >= 79
 			else if (strcmp((char*)xmlChild->name, "weightedPredictionPframes") == 0)
 			{
 				int weightedPredPFrames = X264_WEIGHTP_NONE;
@@ -1734,7 +1902,6 @@ void x264Options::parseAnalyseOptions(xmlNode *node)
 
 				setWeightedPredictionPFrames(weightedPredPFrames);
 			}
-#endif
 			else if (strcmp((char*)xmlChild->name, "weightedPrediction") == 0)
 				setWeightedPrediction(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "directPredictionMode") == 0)
@@ -1828,6 +1995,10 @@ void x264Options::parseRateControlOptions(xmlNode *node)
 				setQuantiserMaximum(atoi(content));
 			else if (strcmp((char*)xmlChild->name, "quantiserStep") == 0)
 				setQuantiserStep(atoi(content));
+#if X264_BUILD > 89
+			else if (strcmp((char*)xmlChild->name, "maximumConstantRateFactor") == 0)
+				setMaximumConstantRateFactor(atoi(content));
+#endif
 			else if (strcmp((char*)xmlChild->name, "averageBitrateTolerance") == 0)
 				setAverageBitrateTolerance(string2Float(content));
 			else if (strcmp((char*)xmlChild->name, "vbvMaximumBitrate") == 0)
@@ -1853,12 +2024,10 @@ void x264Options::parseRateControlOptions(xmlNode *node)
 			}
 			else if (strcmp((char*)xmlChild->name, "adaptiveQuantiserStrength") == 0)
 				setAdaptiveQuantiserStrength(string2Float(content));
-#if X264_BUILD >= 69
 			else if (strcmp((char*)xmlChild->name, "mbTree") == 0)
 				setMbTree(string2Boolean(content));
 			else if (strcmp((char*)xmlChild->name, "frametypeLookahead") == 0)
 				setFrametypeLookahead(atoi(content));
-#endif
 			else if (strcmp((char*)xmlChild->name, "quantiserCurveCompression") == 0)
 				setQuantiserCurveCompression(string2Float(content));
 			else if (strcmp((char*)xmlChild->name, "reduceFluxBeforeCurveCompression") == 0)
