@@ -25,13 +25,12 @@
 #include <libxml/xmlschemas.h>
 
 #include "config.h"
-#include "ADM_default.h"
+#include "ADM_inttype.h"
 #include "ADM_files.h"
 
-#include "../common/PluginOptions.cpp"
 #include "xvidOptions.h"
 
-XvidOptions::XvidOptions(void) : PluginOptions("Xvid", "XvidParam.xsd", DEFAULT_ENCODE_MODE, DEFAULT_ENCODE_MODE_PARAMETER)
+XvidOptions::XvidOptions(void) : PluginOptions(PLUGIN_CONFIG_DIR, "Xvid", "xvid/XvidParam.xsd", DEFAULT_ENCODE_MODE, DEFAULT_ENCODE_MODE_PARAMETER)
 {
 	reset();
 }
@@ -731,7 +730,7 @@ void XvidOptions::addOptionsToXml(xmlNodePtr xmlNodeRoot)
 {
 	const int bufferSize = 100;
 	xmlChar xmlBuffer[bufferSize + 1];
-	xmlNodePtr xmlNodeChild, xmlNodeChild2;
+	xmlNodePtr xmlNodeChild;
 
 	xmlNodeRoot = xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)getOptionsTagRoot(), NULL);
 	xmlNewChild(xmlNodeRoot, NULL, (xmlChar*)"threads", number2String(xmlBuffer, bufferSize, getThreads()));
