@@ -19,28 +19,22 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "ADM_default.h"
-
 #include "ADM_image.h"
-#include "ADM_videoFilter.h"
 #include "ADM_vidASharp_param.h"
 #include "DIA_flyDialog.h"
 #include "DIA_flyAsharp.h"
 
-//
-//
 uint8_t DIA_getASharp(ASHARP_PARAM *param, AVDMGenericVideoStream *in)
 {
-return 1;
+	return 1;
 }
 
-/**************************************/
 uint8_t flyASharp::upload(void)
 {
-        return 1;
+	return 1;
 }
 uint8_t flyASharp::download (void)
 {
-    
-        return 1;
+
+	return 1;
 }
