@@ -4,22 +4,10 @@ function resizeAndFillVideo(targetX, targetY, sourceRatio, destinationRatio)
 {
     var app = new Avidemux();
     var filters = app.video.appliedFilters;
-    var width, height, fps1000;
-
-    if (filters.length > 0)
-    {
-        var lastFilter = app.video.appliedFilters[filters.length - 1];
-
-        width = lastFilter.width;
-        height = lastFilter.height;
-        fps1000 = lastFilter.fps1000;
-    }
-    else
-    {
-        width = app.video.width;
-        height = app.video.height;
-        fps1000 = app.video.fps1000;
-    }
+    var props = getVideoProperties(app.video);
+    var width = props[0];
+    var height = props[1];
+    var fps1000 = props[2];
 
     // Resizing
     var scaledWidth = rescaleVideoDimension(width, sourceRatio, destinationRatio, getColourEncodingSystem(fps1000));
